@@ -113,7 +113,10 @@ async def ping_id_broker(school_authority: SchoolAuthorityConfiguration) -> bool
 
 
 async def create_school_if_missing(
-    ou: str, ldap_access: LDAPAccess, id_broker_school: IDBrokerSchool, logger: logging.Logger
+    ou: str,
+    ldap_access: LDAPAccess,
+    id_broker_school: IDBrokerSchool,
+    logger: logging.Logger,
 ) -> None:
     entries = await ldap_access.search(
         filter_s=f"(&(objectClass=ucsschoolOrganizationalUnit)(ou={escape_filter_chars(ou)}))",
@@ -124,9 +127,13 @@ async def create_school_if_missing(
         display_name = entries[0].displayName.value
         if not await id_broker_school.exists(entry_uuid):
             logger.info("Creating school %r...", ou)
-            await id_broker_school.create(School(id=entry_uuid, name=ou, display_name=display_name))
+            await id_broker_school.create(
+                School(id=entry_uuid, name=ou, display_name=display_name)
+            )
     else:
-        raise IDBrokerNotFoundError(404, f"School {ou!r} does not exist on sender system.")
+        raise IDBrokerNotFoundError(
+            404, f"School {ou!r} does not exist on sender system."
+        )
 
 
 async def create_class_if_missing(
@@ -147,12 +154,17 @@ async def create_class_if_missing(
             logger.info("Creating school class %r in school %r...", school_class, ou)
             await id_broker_school_class.create(
                 SchoolClass(
-                    id=entry_uuid, name=school_class, description=description, school=ou, members=[]
+                    id=entry_uuid,
+                    name=school_class,
+                    description=description,
+                    school=ou,
+                    members=[],
                 )
             )
     else:
         raise IDBrokerNotFoundError(
-            404, f"School class {school_class!r} in school {ou!r} does not exist on sender system."
+            404,
+            f"School class {school_class!r} in school {ou!r} does not exist on sender system.",
         )
 
 
@@ -173,16 +185,26 @@ async def create_work_group_if_missing(
         if not await id_broker_work_group.exists(entry_uuid):
             logger.info("Creating school class %r in school %r...", work_group, ou)
             await id_broker_work_group.create(
-                WorkGroup(id=entry_uuid, name=work_group, description=description, school=ou, members=[])
+                WorkGroup(
+                    id=entry_uuid,
+                    name=work_group,
+                    description=description,
+                    school=ou,
+                    members=[],
+                )
             )
     else:
         raise IDBrokerNotFoundError(
-            404, f"Workgroup {work_group!r} in school {ou!r} does not exist on sender system."
+            404,
+            f"Workgroup {work_group!r} in school {ou!r} does not exist on sender system.",
         )
 
 
 def initial_mode_is_activated(school_authority: SchoolAuthorityConfiguration) -> bool:
-    return school_authority.plugin_configs["id_broker"].get("initial_import_mode", False) is True
+    return (
+        school_authority.plugin_configs["id_broker"].get("initial_import_mode", False)
+        is True
+    )
 
 
 class UcsschoolRoleStringError(Exception):
@@ -212,7 +234,9 @@ role_workgroup: str = "workgroup"
 class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
     _required_search_params = ("id", "school_authority")
 
-    def __init__(self, school_authority: SchoolAuthorityConfiguration, plugin_name: str):
+    def __init__(
+        self, school_authority: SchoolAuthorityConfiguration, plugin_name: str
+    ):
         super(IDBrokerPerSAUserDispatcher, self).__init__(school_authority, plugin_name)
         self.class_dn_regex = school_class_dn_regex()
         self.workgroup_dn_regex = workgroup_dn_regex()
@@ -227,8 +251,12 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
             "legal_wards": "legal_wards",
             "context": "context",
         }
-        self.id_broker_school_class = IDBrokerSchoolClass(self.school_authority, "id_broker")
-        self.id_broker_work_group = IDBrokerWorkGroup(self.school_authority, "id_broker")
+        self.id_broker_school_class = IDBrokerSchoolClass(
+            self.school_authority, "id_broker"
+        )
+        self.id_broker_work_group = IDBrokerWorkGroup(
+            self.school_authority, "id_broker"
+        )
         self.id_broker_school = IDBrokerSchool(self.school_authority, "id_broker")
         self.id_broker_user = IDBrokerUser(self.school_authority, "id_broker")
         self.ldap_access = LDAPAccess()
@@ -237,13 +265,17 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
     def initial_import_mode(self):
         return initial_mode_is_activated(self.school_authority)
 
-    async def create_or_update_preconditions_met(self, obj: ListenerUserAddModifyObject) -> bool:
+    async def create_or_update_preconditions_met(
+        self, obj: ListenerUserAddModifyObject
+    ) -> bool:
         return True
 
     async def print_ids(self, obj: ListenerUserAddModifyObject) -> None:
         self.logger.info(f"Object that is being created or updated: {obj}")
 
-    async def _handle_attr_context(self, obj: ListenerUserAddModifyObject) -> Dict[str, Any]:
+    async def _handle_attr_context(
+        self, obj: ListenerUserAddModifyObject
+    ) -> Dict[str, Any]:
         # Add primary school 1st to context dict (which is always ordered in cpython3). It will then be
         # the 1st in the requests json (at least with the OpenAPI client we're using) and will then
         # hopefully become the primary school at the ID Broker. That is not strictly necessary, as the
@@ -252,7 +284,11 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         schools.remove(obj.school)
         schools.insert(0, obj.school)
         context = {
-            school_name: {"roles": set(obj.school_user_roles), "classes": set(), "workgroups": set()}
+            school_name: {
+                "roles": set(obj.school_user_roles),
+                "classes": set(),
+                "workgroups": set(),
+            }
             for school_name in schools
         }
         for group_dn in obj.object.get("groups", []):
@@ -272,7 +308,9 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
     async def _handle_attr_id(self, obj: ListenerUserAddModifyObject) -> str:
         return obj.id
 
-    async def _handle_attr_legal_guardians(self, obj: ListenerUserAddModifyObject) -> list[str]:
+    async def _handle_attr_legal_guardians(
+        self, obj: ListenerUserAddModifyObject
+    ) -> list[str]:
         record_uids = []
         for dn in obj.legal_guardians:
             user_entries = await self.ldap_access.search(
@@ -291,11 +329,15 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
             record_uids.append(entry_uuid)
         return sorted(record_uids)
 
-    async def _handle_attr_legal_wards(self, obj: ListenerUserAddModifyObject) -> list[str]:
+    async def _handle_attr_legal_wards(
+        self, obj: ListenerUserAddModifyObject
+    ) -> list[str]:
         record_uids = []
         for dn in obj.legal_wards:
             user_entries = await self.ldap_access.search(
-                base=dn, filter_s="(objectClass=ucsschoolStudent)", attributes=["entryUUID"]
+                base=dn,
+                filter_s="(objectClass=ucsschoolStudent)",
+                attributes=["entryUUID"],
             )
             if len(user_entries) < 1:
                 self.logger.warning(f"Legal ward {dn} not found.")
@@ -324,18 +366,32 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         try:
             return await self.id_broker_user.get(obj_id=search_params["id"])
         except IDBrokerNotFoundError:
-            raise UserNotFoundError(f"No user found with search params: {search_params!r}.")
+            raise UserNotFoundError(
+                f"No user found with search params: {search_params!r}."
+            )
 
-    async def _create_schools_and_school_groups_if_missing(self, context: ContextDictType) -> None:
+    async def _create_schools_and_school_groups_if_missing(
+        self, context: ContextDictType
+    ) -> None:
         for school in sorted(context):
-            await create_school_if_missing(school, self.ldap_access, self.id_broker_school, self.logger)
+            await create_school_if_missing(
+                school, self.ldap_access, self.id_broker_school, self.logger
+            )
             for school_class in context[school]["classes"]:
                 await create_class_if_missing(
-                    school_class, school, self.ldap_access, self.id_broker_school_class, self.logger
+                    school_class,
+                    school,
+                    self.ldap_access,
+                    self.id_broker_school_class,
+                    self.logger,
                 )
             for work_group in context[school]["workgroups"]:
                 await create_work_group_if_missing(
-                    work_group, school, self.ldap_access, self.id_broker_work_group, self.logger
+                    work_group,
+                    school,
+                    self.ldap_access,
+                    self.id_broker_work_group,
+                    self.logger,
                 )
 
     async def _school_context_from_ldap_entry(self, ldap_entry):
@@ -345,7 +401,9 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         """
         user_dn_match = self.user_dn_regex.match(ldap_entry.entry_dn)
         if not user_dn_match:
-            self.logger.error(f"dn {ldap_entry.entry_dn!r} does not match {self.user_dn_regex!r}")
+            self.logger.error(
+                f"dn {ldap_entry.entry_dn!r} does not match {self.user_dn_regex!r}"
+            )
             return None
 
         schools = sorted(ldap_entry.ucsschoolSchool)
@@ -371,7 +429,6 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         }
         if ldap_entry.memberOf:
             for group_dn in ldap_entry.memberOf:
-
                 user_dn_match = self.class_dn_regex.match(group_dn)
                 if user_dn_match:
                     name = user_dn_match.groupdict()["name"]
@@ -399,7 +456,9 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
     async def do_create(self, request_body: Dict[str, Any]) -> None:
         """Create a user object at the target."""
         self.logger.info(
-            "Going to create user %r (%r)...", request_body["user_name"], request_body["id"]
+            "Going to create user %r (%r)...",
+            request_body["user_name"],
+            request_body["id"],
         )
         self.logger.debug("request_body=%r", request_body)
         if self.initial_import_mode:
@@ -408,9 +467,13 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         user: User = await self.id_broker_user.create(User(**request_body))
         self.logger.info("User created: %r.", user)
 
-    async def do_modify(self, request_body: Dict[str, Any], api_user_data: User) -> None:
+    async def do_modify(
+        self, request_body: Dict[str, Any], api_user_data: User
+    ) -> None:
         """Modify a user object at the target."""
-        self.logger.info("Going to modify user %r (%r)...", api_user_data.user_name, api_user_data.id)
+        self.logger.info(
+            "Going to modify user %r (%r)...", api_user_data.user_name, api_user_data.id
+        )
         self.logger.debug("request_body=%r", request_body)
         if self.initial_import_mode:
             request_body["context"] = self._empty_groups(request_body["context"])
@@ -420,7 +483,9 @@ class IDBrokerPerSAUserDispatcher(PerSchoolAuthorityUserDispatcherBase):
         user: User = await self.id_broker_user.update(User(**request_body))
         self.logger.info("User modified: %r.", user)
 
-    async def do_remove(self, obj: ListenerGroupRemoveObject, api_user_data: User) -> None:
+    async def do_remove(
+        self, obj: ListenerGroupRemoveObject, api_user_data: User
+    ) -> None:
         """Delete a user object at the target."""
         self.logger.info("Going to delete user: %r...", obj)
         await self.id_broker_user.delete(api_user_data.id)
@@ -432,7 +497,9 @@ class IDBrokerUserDispatcher(UserDispatcherPluginBase):
     per_s_a_handler_class = IDBrokerPerSAUserDispatcher
 
     @hook_impl
-    async def school_authority_ping(self, school_authority: SchoolAuthorityConfiguration) -> bool:
+    async def school_authority_ping(
+        self, school_authority: SchoolAuthorityConfiguration
+    ) -> bool:
         """impl for ucsschool_id_connector.plugins.Postprocessing.school_authority_ping"""
         if not await ping_id_broker(school_authority):
             self.logger.error(
@@ -456,7 +523,9 @@ class IDBrokerUserDispatcher(UserDispatcherPluginBase):
                 # User was not deleted, but has no configured schools left
                 # -> delete user instead of modifying it.
                 self.logger.debug(f"{obj} got removed from all configured schools")
-                await self.handler(school_authority, self.plugin_name).handle_remove(obj)
+                await self.handler(school_authority, self.plugin_name).handle_remove(
+                    obj
+                )
                 return True
             if user_has_unconfigured_schools(obj, configured_schools):
                 # Remove unconfigured schools from user
@@ -495,8 +564,12 @@ def has_workgroup_role(roles: List[str], school: str) -> bool:
 class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
     _required_search_params = ("id", "school_authority")
 
-    def __init__(self, school_authority: SchoolAuthorityConfiguration, plugin_name: str):
-        super(IDBrokerPerSAGroupDispatcher, self).__init__(school_authority, plugin_name)
+    def __init__(
+        self, school_authority: SchoolAuthorityConfiguration, plugin_name: str
+    ):
+        super(IDBrokerPerSAGroupDispatcher, self).__init__(
+            school_authority, plugin_name
+        )
         self.attribute_mapping = {
             "id": "id",
             "name": "name",
@@ -505,9 +578,13 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
             "users": "members",
             "ucsschoolRole": "ucsschoolRole",
         }
-        self.id_broker_work_group = IDBrokerWorkGroup(self.school_authority, "id_broker")
+        self.id_broker_work_group = IDBrokerWorkGroup(
+            self.school_authority, "id_broker"
+        )
         self.id_broker_school = IDBrokerSchool(self.school_authority, "id_broker")
-        self.id_broker_school_class = IDBrokerSchoolClass(self.school_authority, "id_broker")
+        self.id_broker_school_class = IDBrokerSchoolClass(
+            self.school_authority, "id_broker"
+        )
         self.id_broker_user = IDBrokerUser(self.school_authority, "id_broker")
         self.class_dn_regex = school_class_dn_regex()
         self.work_group_dn_regex = workgroup_dn_regex()
@@ -517,7 +594,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
     def initial_import_mode(self):
         return initial_mode_is_activated(self.school_authority)
 
-    async def create_or_update_preconditions_met(self, obj: ListenerGroupAddModifyObject) -> bool:
+    async def create_or_update_preconditions_met(
+        self, obj: ListenerGroupAddModifyObject
+    ) -> bool:
         """Verify preconditions for creating or modifying object on target."""
         return (
             await self.is_schools_class(obj) or await self.is_work_group(obj)
@@ -546,7 +625,11 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
     async def search_params(
         self, obj: Union[ListenerGroupAddModifyObject, ListenerGroupRemoveObject]
     ) -> Dict[str, Any]:
-        return {"school_authority": self.school_authority.name, "id": obj.id, "dn": obj.dn}
+        return {
+            "school_authority": self.school_authority.name,
+            "id": obj.id,
+            "dn": obj.dn,
+        }
 
     async def fetch_obj(self, search_params: Dict[str, Any]) -> SchoolGroupType:
         """
@@ -555,18 +638,24 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
         :return SchoolGroupType: school group object on the ID Broker
         :raises GroupNotFoundError: if it does not exist on the ID Broker
         """
-        self.logger.debug("Retrieving school group with search parameters: %r", search_params)
+        self.logger.debug(
+            "Retrieving school group with search parameters: %r", search_params
+        )
         m = self.class_dn_regex.match(search_params["dn"])
         if m:
             try:
                 return await self.id_broker_school_class.get(obj_id=search_params["id"])
             except (IDBrokerNotFoundError, IDBrokerError):
-                raise GroupNotFoundError(f"No school class found with search params: {search_params!r}.")
+                raise GroupNotFoundError(
+                    f"No school class found with search params: {search_params!r}."
+                )
         else:
             try:
                 return await self.id_broker_work_group.get(obj_id=search_params["id"])
             except (IDBrokerNotFoundError, IDBrokerError):
-                raise GroupNotFoundError(f"No workgroup found with search params: {search_params!r}.")
+                raise GroupNotFoundError(
+                    f"No workgroup found with search params: {search_params!r}."
+                )
 
     async def _handle_attr_id(self, obj: ListenerUserAddModifyObject) -> str:
         return obj.id
@@ -590,9 +679,13 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
                 base=dn, filter_s="(objectClass=*)", attributes=["entryUUID"]
             )
             if len(user_entries) > 1:
-                self.logger.warning(f"Member {dn!r} of group {obj.name!r} was found multiple times.")
+                self.logger.warning(
+                    f"Member {dn!r} of group {obj.name!r} was found multiple times."
+                )
             elif len(user_entries) < 1:
-                self.logger.warning(f"Member {dn!r} of group {obj.name!r} was not found.")
+                self.logger.warning(
+                    f"Member {dn!r} of group {obj.name!r} was not found."
+                )
             else:
                 record_uids.append(str(user_entries[0].entryUUID))
         return sorted(record_uids)
@@ -614,7 +707,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
         name, school = request_body["name"], request_body["school"]
         if self.initial_import_mode:
             self.logger.debug(
-                "Skipping creation of school group %r in  %r in initial import mode.", name, school
+                "Skipping creation of school group %r in  %r in initial import mode.",
+                name,
+                school,
             )
             return
         self.logger.info(
@@ -623,9 +718,13 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
             school,
             request_body,
         )
-        await create_school_if_missing(school, self.ldap_access, self.id_broker_school, self.logger)
+        await create_school_if_missing(
+            school, self.ldap_access, self.id_broker_school, self.logger
+        )
         try:
-            if has_workgroup_role(request_body["ucsschoolRole"], request_body["school"]):
+            if has_workgroup_role(
+                request_body["ucsschoolRole"], request_body["school"]
+            ):
                 g = WorkGroup(**request_body)
                 self.logger.info("Creating work group %s", g)
                 await self.id_broker_work_group.create(g)
@@ -634,8 +733,13 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
                 self.logger.info("Creating school class %s", g)
                 await self.id_broker_school_class.create(g)
         except IDBrokerError as exc:
-            if exc.status == status.HTTP_422_UNPROCESSABLE_ENTITY and "member" in str(exc).lower():
-                self.logger.error("Unknown member(s) when creating school group %r: %s", name, exc)
+            if (
+                exc.status == status.HTTP_422_UNPROCESSABLE_ENTITY
+                and "member" in str(exc).lower()
+            ):
+                self.logger.error(
+                    "Unknown member(s) when creating school group %r: %s", name, exc
+                )
                 await self._fix_school_group_members(g)
             else:
                 raise
@@ -648,7 +752,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
         name, school = request_body["name"], request_body["school"]
         if self.initial_import_mode:
             self.logger.debug(
-                "Skipping modification of school group %r in %r in initial import mode.", name, school
+                "Skipping modification of school group %r in %r in initial import mode.",
+                name,
+                school,
             )
             return
         self.logger.info(
@@ -659,7 +765,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
         )
 
         try:
-            if has_workgroup_role(request_body["ucsschoolRole"], request_body["school"]):
+            if has_workgroup_role(
+                request_body["ucsschoolRole"], request_body["school"]
+            ):
                 g = WorkGroup(**request_body)
                 self.logger.info("Updating work group %s", g)
                 await self.id_broker_work_group.update(g)
@@ -668,7 +776,10 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
                 self.logger.info("Updating school class %s", g)
                 await self.id_broker_school_class.update(g)
         except IDBrokerError as exc:
-            if exc.status == status.HTTP_422_UNPROCESSABLE_ENTITY and "member" in str(exc).lower():
+            if (
+                exc.status == status.HTTP_422_UNPROCESSABLE_ENTITY
+                and "member" in str(exc).lower()
+            ):
                 self.logger.error(
                     "Unknown member(s) when updating school group %r: %s",
                     api_school_group_data.name,
@@ -696,7 +807,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
             else:
                 await self.id_broker_work_group.delete(api_school_group_data.id)
         except (IDBrokerNotFoundError, IDBrokerError):
-            self.logger.warning(f"No school group found with id: {api_school_group_data.id!r}.")
+            self.logger.warning(
+                f"No school group found with id: {api_school_group_data.id!r}."
+            )
         self.logger.info("Group deleted: %r.", api_school_group_data)
 
     async def _fix_school_group_members(self, school_group: SchoolGroupType):
@@ -708,7 +821,9 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
             else:
                 await self.id_broker_work_group.get(obj_id=school_group.id)
         except (IDBrokerNotFoundError, IDBrokerError):
-            self.logger.info("School group does %r not exists, creating...", school_group)
+            self.logger.info(
+                "School group does %r not exists, creating...", school_group
+            )
             members = school_group.members.copy()
             school_group.members.clear()
             if isinstance(school_group, SchoolClass):
@@ -722,17 +837,26 @@ class IDBrokerPerSAGroupDispatcher(PerSchoolAuthorityGroupDispatcherBase):
         for user_id in school_group.members:
             try:
                 user: User = await self.id_broker_user.get(obj_id=user_id)
-                self.logger.debug("Found member of %r at ID Broker server: %r.", school_group, user)
+                self.logger.debug(
+                    "Found member of %r at ID Broker server: %r.", school_group, user
+                )
                 new_members.append(user_id)
             except IDBrokerNotFoundError:
-                self.logger.error("Missing member of %r at ID Broker server: %r.", school_group, user_id)
+                self.logger.error(
+                    "Missing member of %r at ID Broker server: %r.",
+                    school_group,
+                    user_id,
+                )
                 filter_s = f"(&(objectClass=posixAccount)(entryUUID={user_id}))"
                 results = await self.ldap_access.search(filter_s=filter_s)
                 if len(results) == 1:
-                    self.logger.error("Missing member DN in local LDAP is: %r", results[0].entry_dn)
+                    self.logger.error(
+                        "Missing member DN in local LDAP is: %r", results[0].entry_dn
+                    )
                 else:
                     self.logger.error(
-                        "Could not find user in local LDAP when searching with %r.", filter_s
+                        "Could not find user in local LDAP when searching with %r.",
+                        filter_s,
                     )
         if new_members:
             self.logger.info(
@@ -754,7 +878,9 @@ class IDBrokerGroupDispatcher(GroupDispatcherPluginBase):
     per_s_a_handler_class = IDBrokerPerSAGroupDispatcher
 
     @hook_impl
-    async def school_authority_ping(self, school_authority: SchoolAuthorityConfiguration) -> bool:
+    async def school_authority_ping(
+        self, school_authority: SchoolAuthorityConfiguration
+    ) -> bool:
         """impl for ucsschool_id_connector.plugins.Postprocessing.school_authority_ping"""
         if not await ping_id_broker(school_authority):
             self.logger.error(
