@@ -36,7 +36,12 @@ import faker
 import httpx
 import pytest
 import pytest_asyncio
-from tenacity import AsyncRetrying, retry_if_exception_type, stop_after_attempt, wait_fixed
+from tenacity import (
+    AsyncRetrying,
+    retry_if_exception_type,
+    stop_after_attempt,
+    wait_fixed,
+)
 
 import ucsschool_id_connector.plugin_loader
 from ucsschool.kelvin.client import (
@@ -100,7 +105,9 @@ async def new_school_auth(
     kelvin_school = KelvinSchool(
         name=f"{s_a_name}-{school_name}",
         display_name=f"{s_a_name} {school_name}",
-        educational_servers=[f"{zlib.crc32(s_a_name.encode())}-dc"],  # crc32 > 10 ints > total: 13 chars
+        educational_servers=[
+            f"{zlib.crc32(s_a_name.encode())}-dc"
+        ],  # crc32 > 10 ints > total: 13 chars
         session=kelvin_session(id_broker_fqdn),
     )
     data = kelvin_school._to_kelvin_request_data()
@@ -133,9 +140,9 @@ def get_schools(school_auth_conf, kelvin_session, id_broker_fqdn):
     async def _get_schools(s_a_name: str) -> List[KelvinSchool]:
         return [
             school
-            async for school in KelvinSchoolResource(session=kelvin_session(id_broker_fqdn)).search(
-                name=f"{s_a_name}-*"
-            )
+            async for school in KelvinSchoolResource(
+                session=kelvin_session(id_broker_fqdn)
+            ).search(name=f"{s_a_name}-*")
         ]
 
     async def _func(s_a_name: str) -> List[KelvinSchool]:
@@ -144,7 +151,9 @@ def get_schools(school_auth_conf, kelvin_session, id_broker_fqdn):
             school_name = fake.user_name()
             id_broker_school = IDBrokerSchool(school_auth_conf, "id_broker")
             school_1 = School(
-                id=fake.uuid4(), name=school_name, display_name=f"{s_a_name} {school_name}"
+                id=fake.uuid4(),
+                name=school_name,
+                display_name=f"{s_a_name} {school_name}",
             )
             await id_broker_school.create(school_1)
             await asyncio.sleep(4)
@@ -173,7 +182,13 @@ def a_id_broker_user():
             user_name=fake.user_name(),
             first_name=fake.first_name(),
             last_name=fake.last_name(),
-            context={school_name: SchoolContext(classes=classes, roles=roles, workgroups=workgroups)},
+            legal_guardians=[],
+            legal_wards=[],
+            context={
+                school_name: SchoolContext(
+                    classes=classes, roles=roles, workgroups=workgroups
+                )
+            },
         )
 
     return _func
@@ -210,32 +225,40 @@ def get_kelvin_user(id_broker_fqdn, kelvin_session):
     async def _func(s_a_name: str, user_name: str) -> KelvinUser:
         if s_a_name not in user_name:
             user_name = f"{s_a_name}-{user_name}"
-        return await KelvinUserResource(session=kelvin_session(id_broker_fqdn)).get(name=f"{user_name}")
+        return await KelvinUserResource(session=kelvin_session(id_broker_fqdn)).get(
+            name=f"{user_name}"
+        )
 
     return _func
 
 
 @pytest.fixture(scope="session")
 def get_kelvin_school_class(id_broker_fqdn, kelvin_session):
-    async def _func(s_a_name: str, class_name: str, school_name: str) -> KelvinSchoolClass:
-        return await KelvinSchoolClassResource(session=kelvin_session(id_broker_fqdn)).get(
-            name=class_name, school=f"{s_a_name}-{school_name}"
-        )
+    async def _func(
+        s_a_name: str, class_name: str, school_name: str
+    ) -> KelvinSchoolClass:
+        return await KelvinSchoolClassResource(
+            session=kelvin_session(id_broker_fqdn)
+        ).get(name=class_name, school=f"{s_a_name}-{school_name}")
 
     return _func
 
 
 @pytest.fixture(scope="session")
 def get_kelvin_workgroup(id_broker_fqdn, kelvin_session):
-    async def _func(s_a_name: str, workgroup_name: str, school_name: str) -> KelvinWorkGroup:
-        return await KelvinWorkGroupResource(session=kelvin_session(id_broker_fqdn)).get(
-            name=workgroup_name, school=f"{s_a_name}-{school_name}"
-        )
+    async def _func(
+        s_a_name: str, workgroup_name: str, school_name: str
+    ) -> KelvinWorkGroup:
+        return await KelvinWorkGroupResource(
+            session=kelvin_session(id_broker_fqdn)
+        ).get(name=workgroup_name, school=f"{s_a_name}-{school_name}")
 
     return _func
 
 
-def compare_kelvin_and_id_broker_user(kelvin_user: KelvinUser, id_broker_user: User, s_a_name: str):
+def compare_kelvin_and_id_broker_user(
+    kelvin_user: KelvinUser, id_broker_user: User, s_a_name: str
+):
     assert kelvin_user.record_uid == id_broker_user.id
     assert kelvin_user.source_uid == s_a_name
     assert kelvin_user.firstname == id_broker_user.first_name
@@ -244,12 +267,14 @@ def compare_kelvin_and_id_broker_user(kelvin_user: KelvinUser, id_broker_user: U
     for school, school_context in id_broker_user.context.items():
         idb_school = f"{s_a_name}-{school}"
         assert idb_school in kelvin_user.schools
-        assert {f"{role}:school:{idb_school}" for role in school_context.roles}.issubset(
-            set(kelvin_user.ucsschool_roles)
-        )
+        assert {
+            f"{role}:school:{idb_school}" for role in school_context.roles
+        }.issubset(set(kelvin_user.ucsschool_roles))
         if school_context.classes:
             assert idb_school in kelvin_user.school_classes
-            assert set(school_context.classes) == set(kelvin_user.school_classes[idb_school])
+            assert set(school_context.classes) == set(
+                kelvin_user.school_classes[idb_school]
+            )
 
 
 def compare_kelvin_and_id_broker_school(
@@ -262,9 +287,13 @@ def compare_kelvin_and_id_broker_school(
 
 @pytest.fixture
 def compare_kelvin_and_id_broker_school_class(get_kelvin_user):
-    async def _func(kelvin_class: KelvinSchoolClass, id_broker_class: SchoolClass, s_a_name: str):
+    async def _func(
+        kelvin_class: KelvinSchoolClass, id_broker_class: SchoolClass, s_a_name: str
+    ):
         assert kelvin_class.name == id_broker_class.name
-        kelvin_class.description = "" if kelvin_class.description is None else kelvin_class.description
+        kelvin_class.description = (
+            "" if kelvin_class.description is None else kelvin_class.description
+        )
         assert kelvin_class.description == id_broker_class.description
         assert kelvin_class.school == f"{s_a_name}-{id_broker_class.school}"
         kelvin_users: List[KelvinUser] = [
@@ -277,7 +306,9 @@ def compare_kelvin_and_id_broker_school_class(get_kelvin_user):
 
 @pytest.fixture
 def compare_kelvin_and_id_broker_workgroup(get_kelvin_user):
-    async def _func(kelvin_workgroup: KelvinWorkGroup, id_broker_workgroup: WorkGroup, s_a_name: str):
+    async def _func(
+        kelvin_workgroup: KelvinWorkGroup, id_broker_workgroup: WorkGroup, s_a_name: str
+    ):
         assert kelvin_workgroup.name == id_broker_workgroup.name
         kelvin_workgroup.description = (
             "" if kelvin_workgroup.description is None else kelvin_workgroup.description
@@ -285,9 +316,12 @@ def compare_kelvin_and_id_broker_workgroup(get_kelvin_user):
         assert kelvin_workgroup.description == id_broker_workgroup.description
         assert kelvin_workgroup.school == f"{s_a_name}-{id_broker_workgroup.school}"
         kelvin_users: List[KelvinUser] = [
-            await get_kelvin_user(s_a_name, username) for username in kelvin_workgroup.users
+            await get_kelvin_user(s_a_name, username)
+            for username in kelvin_workgroup.users
         ]
-        assert set(u.record_uid for u in kelvin_users) == set(id_broker_workgroup.members)
+        assert set(u.record_uid for u in kelvin_users) == set(
+            id_broker_workgroup.members
+        )
 
     return _func
 
@@ -302,12 +336,16 @@ async def schedule_delete_kelvin_user(get_kelvin_user):
     yield _func
 
     for s_a_and_user_name in s_a_and_user_names:
-        print(f"Deleting Kelvin user '{s_a_and_user_name[0]}-{s_a_and_user_name[1]}'...")
+        print(
+            f"Deleting Kelvin user '{s_a_and_user_name[0]}-{s_a_and_user_name[1]}'..."
+        )
         try:
             kelvin_user: KelvinUser = await get_kelvin_user(*s_a_and_user_name)
             await kelvin_user.delete()
         except KelvinNoObject:
-            print(f"Kelvin user '{s_a_and_user_name[0]}-{s_a_and_user_name[1]}' does not exist.")
+            print(
+                f"Kelvin user '{s_a_and_user_name[0]}-{s_a_and_user_name[1]}' does not exist."
+            )
     t_wait = 20
     print(f"Waiting for {t_wait} seconds after deletion...")
     await asyncio.sleep(t_wait)
@@ -319,7 +357,9 @@ def delete_kelvin_school(kelvin_session, id_broker_fqdn):
         session = kelvin_session(id_broker_fqdn)
         schools = [
             school
-            async for school in KelvinSchoolResource(session=session).search(name=f"{s_a_name}-{name}")
+            async for school in KelvinSchoolResource(session=session).search(
+                name=f"{s_a_name}-{name}"
+            )
         ]
         if not schools:
             print(f"*** delete_kelvin_school(): no such school: '{s_a_name}-{name}'.")
@@ -338,7 +378,9 @@ def delete_kelvin_school(kelvin_session, id_broker_fqdn):
 
 
 @pytest_asyncio.fixture
-async def schedule_delete_kelvin_school(delete_kelvin_school, school_auth_conf, kelvin_session):
+async def schedule_delete_kelvin_school(
+    delete_kelvin_school, school_auth_conf, kelvin_session
+):
     s_a_and_school_names: List[Tuple[str, str]] = []
 
     def _func(s_a_name: str, name: str):
@@ -364,9 +406,13 @@ async def schedule_delete_kelvin_school_class(get_kelvin_school_class):
     yield _func
 
     for s_a_name, name, school in s_a_and_sc_names:
-        print(f"Deleting Kelvin school class {name!r} at school {school!r} (auth: {s_a_name!r})...")
+        print(
+            f"Deleting Kelvin school class {name!r} at school {school!r} (auth: {s_a_name!r})..."
+        )
         try:
-            kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(s_a_name, name, school)
+            kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(
+                s_a_name, name, school
+            )
             await kelvin_class.delete()
         except KelvinNoObject:
             print(
@@ -388,9 +434,13 @@ async def schedule_delete_kelvin_workgroup(get_kelvin_workgroup):
     yield _func
 
     for s_a_name, name, school in s_a_and_wg_names:
-        print(f"Deleting Kelvin work group {name!r} at school {school!r} (auth: {s_a_name!r})...")
+        print(
+            f"Deleting Kelvin work group {name!r} at school {school!r} (auth: {s_a_name!r})..."
+        )
         try:
-            kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(s_a_name, name, school)
+            kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(
+                s_a_name, name, school
+            )
             await kelvin_workgroup.delete()
         except KelvinNoObject:
             print(
@@ -454,7 +504,9 @@ async def test_school_create(
     id_broker_school = IDBrokerSchool(school_auth_conf, "id_broker")
     s_a_name = id_broker_school.school_authority_name
     school_name = fake.user_name()
-    school_1 = School(id=fake.uuid4(), name=school_name, display_name=f"{s_a_name} {school_name}")
+    school_1 = School(
+        id=fake.uuid4(), name=school_name, display_name=f"{s_a_name} {school_name}"
+    )
     schedule_delete_kelvin_school(s_a_name, school_name)
     school_2 = await id_broker_school.create(school_1)
     assert school_1 == school_2
@@ -462,7 +514,9 @@ async def test_school_create(
     s_a_schools: List[KelvinSchool] = await get_schools(s_a_name)
     kelvin_school_name = f"{s_a_name}-{school_name}"
     assert kelvin_school_name in {school.name for school in s_a_schools}
-    kelvin_school = [school for school in s_a_schools if school.name == kelvin_school_name][0]
+    kelvin_school = [
+        school for school in s_a_schools if school.name == kelvin_school_name
+    ][0]
     compare_kelvin_and_id_broker_school(kelvin_school, school_2, s_a_name)
 
 
@@ -475,7 +529,9 @@ async def test_school_conflict_create(
     id_broker_school = IDBrokerSchool(school_auth_conf, "id_broker")
     s_a_name = id_broker_school.school_authority_name
     school_name = fake.user_name()
-    school_1 = School(id=fake.uuid4(), name=school_name, display_name=f"{s_a_name} {school_name}")
+    school_1 = School(
+        id=fake.uuid4(), name=school_name, display_name=f"{s_a_name} {school_name}"
+    )
     schedule_delete_kelvin_school(s_a_name, school_name)
     school_2 = await id_broker_school.create(school_1)
     assert school_1 == school_2
@@ -483,7 +539,9 @@ async def test_school_conflict_create(
     s_a_schools: List[KelvinSchool] = await get_schools(s_a_name)
     kelvin_school_name = f"{s_a_name}-{school_name}"
     assert kelvin_school_name in {school.name for school in s_a_schools}
-    kelvin_school = [school for school in s_a_schools if school.name == kelvin_school_name][0]
+    kelvin_school = [
+        school for school in s_a_schools if school.name == kelvin_school_name
+    ][0]
     compare_kelvin_and_id_broker_school(kelvin_school, school_2, s_a_name)
     school_1.id = fake.uuid4()
     with pytest.raises(IDBrokerError):
@@ -500,7 +558,9 @@ async def test_school_exists(
     s_a_name = id_broker_school.school_authority_name
     s_a_schools: List[KelvinSchool] = await get_schools(s_a_name)
     kelvin_school = random.choice(s_a_schools)
-    res = await id_broker_school.exists(kelvin_school.udm_properties["ucsschoolRecordUID"])
+    res = await id_broker_school.exists(
+        kelvin_school.udm_properties["ucsschoolRecordUID"]
+    )
     assert res is True
     res = await id_broker_school.exists(fake.uuid4())
     assert res is False
@@ -515,7 +575,9 @@ async def test_school_get(
     s_a_name = id_broker_school.school_authority_name
     s_a_schools: List[KelvinSchool] = await get_schools(s_a_name)
     kelvin_school = random.choice(s_a_schools)
-    school = await id_broker_school.get(kelvin_school.udm_properties["ucsschoolRecordUID"])
+    school = await id_broker_school.get(
+        kelvin_school.udm_properties["ucsschoolRecordUID"]
+    )
     compare_kelvin_and_id_broker_school(kelvin_school, school, s_a_name)
 
 
@@ -533,14 +595,16 @@ async def test_school_delete(
     assert res is True
     await id_broker_school.delete(kelvin_school.udm_properties["ucsschoolRecordUID"])
     async for attempt in AsyncRetrying(
-        stop=stop_after_attempt(5), wait=wait_fixed(10), retry=retry_if_exception_type(AssertionError)
+        stop=stop_after_attempt(5),
+        wait=wait_fixed(10),
+        retry=retry_if_exception_type(AssertionError),
     ):
         with attempt:
             assert await id_broker_school.exists(school_id) is False
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_school_class_create(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -576,12 +640,14 @@ async def test_school_class_create(
     schedule_delete_kelvin_school_class(s_a_name, class_name, school)
     sc_2 = await id_broker_sc.create(sc_1)
     assert sc_1 == sc_2
-    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(s_a_name, class_name, school)
+    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(
+        s_a_name, class_name, school
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_class, sc_2, s_a_name)
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_school_class_conflict_create(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -617,12 +683,16 @@ async def test_school_class_conflict_create(
     schedule_delete_kelvin_school_class(s_a_name, class_name, school)
     sc_2 = await id_broker_sc.create(sc_1)
     assert sc_1 == sc_2
-    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(s_a_name, class_name, school)
+    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(
+        s_a_name, class_name, school
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_class, sc_2, s_a_name)
     sc_1.id = fake.uuid4()
     sc_2 = await id_broker_sc.create(sc_1)
     assert sc_1 == sc_2
-    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(s_a_name, class_name, school)
+    kelvin_class: KelvinSchoolClass = await get_kelvin_school_class(
+        s_a_name, class_name, school
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_class, sc_2, s_a_name)
 
 
@@ -640,7 +710,10 @@ async def test_school_class_exists(
     kelvin_sc = KelvinSchoolClass(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
@@ -667,18 +740,23 @@ async def test_school_class_get(
     kelvin_sc = KelvinSchoolClass(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_school_class(s_a_name, kelvin_sc.name, school)
     await kelvin_sc.save()
-    sc: SchoolClass = await id_broker_sc.get(kelvin_sc.udm_properties["ucsschoolRecordUID"])
+    sc: SchoolClass = await id_broker_sc.get(
+        kelvin_sc.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_sc, sc, s_a_name)
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_school_class_update(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -697,13 +775,18 @@ async def test_school_class_update(
     kelvin_sc_1 = KelvinSchoolClass(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_school_class(s_a_name, kelvin_sc_1.name, school)
     await kelvin_sc_1.save()
-    sc_1: SchoolClass = await id_broker_sc.get(kelvin_sc_1.udm_properties["ucsschoolRecordUID"])
+    sc_1: SchoolClass = await id_broker_sc.get(
+        kelvin_sc_1.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_sc_1, sc_1, s_a_name)
     kelvin_user: KelvinUser = a_kelvin_user(
         s_a_name=s_a_name,
@@ -718,10 +801,14 @@ async def test_school_class_update(
     sc_1.members.clear()
     sc_1.members.append(kelvin_user.record_uid)
     sc_2: SchoolClass = await id_broker_sc.update(sc_1)
-    sc_3: SchoolClass = await id_broker_sc.get(kelvin_sc_1.udm_properties["ucsschoolRecordUID"])
+    sc_3: SchoolClass = await id_broker_sc.get(
+        kelvin_sc_1.udm_properties["ucsschoolRecordUID"]
+    )
     assert sc_2 == sc_3
     assert sc_1 == sc_2
-    kelvin_sc_2: KelvinSchoolClass = await get_kelvin_school_class(s_a_name, kelvin_sc_1.name, school)
+    kelvin_sc_2: KelvinSchoolClass = await get_kelvin_school_class(
+        s_a_name, kelvin_sc_1.name, school
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_sc_2, sc_3, s_a_name)
 
 
@@ -741,14 +828,19 @@ async def test_school_class_delete(
     kelvin_sc = KelvinSchoolClass(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_school_class(s_a_name, kelvin_sc.name, school)
     await kelvin_sc.save()
     await asyncio.sleep(4)
-    sc: SchoolClass = await id_broker_sc.get(kelvin_sc.udm_properties["ucsschoolRecordUID"])
+    sc: SchoolClass = await id_broker_sc.get(
+        kelvin_sc.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_school_class(kelvin_sc, sc, s_a_name)
     await id_broker_sc.delete(kelvin_sc.udm_properties["ucsschoolRecordUID"])
     with pytest.raises(KelvinNoObject):
@@ -756,7 +848,7 @@ async def test_school_class_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_workgroup_create(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -792,12 +884,14 @@ async def test_workgroup_create(
     schedule_delete_kelvin_workgroup(s_a_name, workgroup_name, school)
     wg_2 = await id_broker_wg.create(wg_1)
     assert wg_1 == wg_2
-    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(s_a_name, workgroup_name, school)
+    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(
+        s_a_name, workgroup_name, school
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_workgroup, wg_2, s_a_name)
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_workgroup_conflict_create(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -833,12 +927,16 @@ async def test_workgroup_conflict_create(
     schedule_delete_kelvin_workgroup(s_a_name, workgroup_name, school)
     wg_2 = await id_broker_wg.create(wg_1)
     assert wg_1 == wg_2
-    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(s_a_name, workgroup_name, school)
+    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(
+        s_a_name, workgroup_name, school
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_workgroup, wg_2, s_a_name)
     wg_1.id = fake.uuid4()
     wg_2 = await id_broker_wg.create(wg_1)
     assert wg_1 == wg_2
-    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(s_a_name, workgroup_name, school)
+    kelvin_workgroup: KelvinWorkGroup = await get_kelvin_workgroup(
+        s_a_name, workgroup_name, school
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_workgroup, wg_2, s_a_name)
 
 
@@ -856,7 +954,10 @@ async def test_workgroup_exists(
     kelvin_wg = KelvinWorkGroup(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         description=f"desc {s_a_name} {fake.user_name()}",
         users=[],
         session=kelvin_session(id_broker_fqdn),
@@ -884,18 +985,23 @@ async def test_workgroup_get(
     kelvin_wg = KelvinWorkGroup(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_workgroup(s_a_name, kelvin_wg.name, school)
     await kelvin_wg.save()
-    wg: WorkGroup = await id_broker_wg.get(kelvin_wg.udm_properties["ucsschoolRecordUID"])
+    wg: WorkGroup = await id_broker_wg.get(
+        kelvin_wg.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_wg, wg, s_a_name)
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_workgroup_update(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -914,13 +1020,18 @@ async def test_workgroup_update(
     kelvin_wg_1 = KelvinWorkGroup(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_workgroup(s_a_name, kelvin_wg_1.name, school)
     await kelvin_wg_1.save()
-    wg_1: WorkGroup = await id_broker_wg.get(kelvin_wg_1.udm_properties["ucsschoolRecordUID"])
+    wg_1: WorkGroup = await id_broker_wg.get(
+        kelvin_wg_1.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_wg_1, wg_1, s_a_name)
     kelvin_user: KelvinUser = a_kelvin_user(
         s_a_name=s_a_name,
@@ -935,10 +1046,14 @@ async def test_workgroup_update(
     wg_1.members.clear()
     wg_1.members.append(kelvin_user.record_uid)
     wg_2: WorkGroup = await id_broker_wg.update(wg_1)
-    wg_3: WorkGroup = await id_broker_wg.get(kelvin_wg_1.udm_properties["ucsschoolRecordUID"])
+    wg_3: WorkGroup = await id_broker_wg.get(
+        kelvin_wg_1.udm_properties["ucsschoolRecordUID"]
+    )
     assert wg_2 == wg_3
     assert wg_1 == wg_2
-    kelvin_wg_2: KelvinWorkGroup = await get_kelvin_workgroup(s_a_name, kelvin_wg_1.name, school)
+    kelvin_wg_2: KelvinWorkGroup = await get_kelvin_workgroup(
+        s_a_name, kelvin_wg_1.name, school
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_wg_2, wg_3, s_a_name)
 
 
@@ -958,14 +1073,19 @@ async def test_workgroup_delete(
     kelvin_wg = KelvinWorkGroup(
         name=fake.user_name(),
         school=f"{s_a_name}-{school}",
-        udm_properties={"ucsschoolRecordUID": fake.uuid4(), "ucsschoolSourceUID": s_a_name},
+        udm_properties={
+            "ucsschoolRecordUID": fake.uuid4(),
+            "ucsschoolSourceUID": s_a_name,
+        },
         users=[],
         session=kelvin_session(id_broker_fqdn),
     )
     schedule_delete_kelvin_workgroup(s_a_name, kelvin_wg.name, school)
     await kelvin_wg.save()
     await asyncio.sleep(4)
-    wg: WorkGroup = await id_broker_wg.get(kelvin_wg.udm_properties["ucsschoolRecordUID"])
+    wg: WorkGroup = await id_broker_wg.get(
+        kelvin_wg.udm_properties["ucsschoolRecordUID"]
+    )
     await compare_kelvin_and_id_broker_workgroup(kelvin_wg, wg, s_a_name)
     await id_broker_wg.delete(kelvin_wg.udm_properties["ucsschoolRecordUID"])
     with pytest.raises(KelvinNoObject):
@@ -973,7 +1093,7 @@ async def test_workgroup_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_create(
     get_kelvin_user,
     schedule_delete_kelvin_school_class,
@@ -1008,7 +1128,7 @@ async def test_user_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_conflict_create(
     get_kelvin_user,
     schedule_delete_kelvin_school_class,
@@ -1048,7 +1168,7 @@ async def test_user_conflict_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_delete(
     get_kelvin_user,
     id_broker_fqdn: str,
@@ -1081,7 +1201,7 @@ async def test_user_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_exists(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1114,7 +1234,7 @@ async def test_user_exists(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_get(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1144,7 +1264,7 @@ async def test_user_get(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_update(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1185,16 +1305,18 @@ async def test_user_update(
     get_updated_id_broker_user: User = await id_broker_user.get(orig_id_broker_user.id)
     assert updated_id_broker_user == get_updated_id_broker_user
     orig_user_classes = [
-        (school, set(context.classes)) for school, context in orig_id_broker_user.context.items()
+        (school, set(context.classes))
+        for school, context in orig_id_broker_user.context.items()
     ]
     updated_user_classes = [
-        (school, set(context.classes)) for school, context in updated_id_broker_user.context.items()
+        (school, set(context.classes))
+        for school, context in updated_id_broker_user.context.items()
     ]
     assert orig_user_classes == updated_user_classes
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
 async def test_user_update_change_username(
     get_kelvin_user,
     id_broker_fqdn: str,
@@ -1238,3 +1360,135 @@ async def test_user_update_change_username(
         await get_kelvin_user(s_a_name, old_user_name)
     kelvin_user_2 = await get_kelvin_user(s_a_name, user_3.user_name)
     assert kelvin_user_2.name == f"{s_a_name}-{user_3.user_name}"
+
+
+@pytest.mark.asyncio
+@pytest.mark.parametrize(
+    "legal_ward_count", [1, 3], ids=lambda legal_ward_count: f"{legal_ward_count=}"
+)
+async def test_legal_guardian_create(
+    id_broker_fqdn: str,
+    kelvin_session,
+    schedule_delete_kelvin_school_class,
+    schedule_delete_kelvin_user,
+    school_auth_conf: SchoolAuthorityConfiguration,
+    a_kelvin_user,
+    a_id_broker_user,
+    a_school_name,
+    legal_ward_count,
+):
+    """Test creation of a legal guardian
+
+    Create a legal guardian with some legal wards and check that
+    `legal_wards` and `legal_guardians` attributes on all related objects are correct
+    """
+    id_broker_user = IDBrokerUser(school_auth_conf, "id_broker")
+    s_a_name = id_broker_user.school_authority_name
+    school: str = await a_school_name(s_a_name)
+    class_name = fake.user_name()
+
+    kelvin_user_students: list[KelvinUser] = [
+        a_kelvin_user(
+            s_a_name=s_a_name,
+            session=kelvin_session(id_broker_fqdn),
+            school_name=school,
+            classes=[class_name],
+            roles=["student"],
+        )
+        for _ in range(legal_ward_count)
+    ]
+
+    legal_guardian_user: User = await a_id_broker_user(
+        school_name=school,
+        classes=[],
+        workgroups=[],
+        roles=["legal_guardian"],
+    )
+
+    legal_wards_record_uids = [
+        kelvin_user_student.record_uid for kelvin_user_student in kelvin_user_students
+    ]
+    legal_guardian_user.legal_wards = legal_wards_record_uids
+
+    schedule_delete_kelvin_school_class(s_a_name, class_name, school)
+
+    for kelvin_user_student in kelvin_user_students:
+        schedule_delete_kelvin_user(
+            s_a_name, kelvin_user_student.name.split("-", 1)[-1]
+        )
+        await kelvin_user_student.save()
+
+    schedule_delete_kelvin_user(
+        s_a_name, legal_guardian_user.user_name.split("-", 1)[-1]
+    )
+    await id_broker_user.create(legal_guardian_user)
+
+    for kelvin_user_student in kelvin_user_students:
+        student_user: User = await id_broker_user.get(kelvin_user_student.record_uid)
+        assert student_user.legal_guardians == [legal_guardian_user.id]
+
+    legal_guardian_user: User = await id_broker_user.get(legal_guardian_user.id)
+    assert set(legal_guardian_user.legal_wards) == set(legal_wards_record_uids)
+
+
+@pytest.mark.asyncio
+@pytest.mark.parametrize("legal_guardian_count", [1, 3])
+async def test_legal_ward_create(
+    id_broker_fqdn: str,
+    kelvin_session,
+    schedule_delete_kelvin_school_class,
+    schedule_delete_kelvin_user,
+    school_auth_conf: SchoolAuthorityConfiguration,
+    create_school_class,
+    a_kelvin_user,
+    a_id_broker_user,
+    a_school_name,
+    legal_guardian_count,
+):
+    id_broker_user = IDBrokerUser(school_auth_conf, "id_broker")
+    id_broker_sc = IDBrokerSchoolClass(school_auth_conf, "id_broker")
+
+    s_a_name = id_broker_user.school_authority_name
+    school: str = await a_school_name(s_a_name)
+    class_name = fake.user_name()
+
+    kelvin_user_legal_guardians: list[KelvinUser] = [
+        a_kelvin_user(
+            s_a_name=s_a_name,
+            session=kelvin_session(id_broker_fqdn),
+            school_name=school,
+            classes=[],
+            roles=["legal_guardian"],
+        )
+        for _ in range(legal_guardian_count)
+    ]
+
+    legal_ward_user: User = await a_id_broker_user(
+        school_name=school,
+        classes=[class_name],
+        workgroups=[],
+        roles=["student"],
+    )
+
+    legal_guardians_record_uids = [
+        kelvin_user.record_uid for kelvin_user in kelvin_user_legal_guardians
+    ]
+    legal_ward_user.legal_guardians = legal_guardians_record_uids
+
+    await create_school_class(class_name, school, s_a_name, [], id_broker_sc)
+    schedule_delete_kelvin_school_class(s_a_name, class_name, school)
+
+    for kelvin_user in kelvin_user_legal_guardians:
+        schedule_delete_kelvin_user(s_a_name, kelvin_user.name.split("-", 1)[-1])
+        await kelvin_user.save()
+
+    schedule_delete_kelvin_user(s_a_name, legal_ward_user.user_name.split("-", 1)[-1])
+    await id_broker_user.create(legal_ward_user)
+    for kelvin_user_legal_guardian in kelvin_user_legal_guardians:
+        legal_guardian_user: User = await id_broker_user.get(
+            kelvin_user_legal_guardian.record_uid
+        )
+        assert legal_guardian_user.legal_wards == [legal_ward_user.id]
+
+    legal_ward_user: User = await id_broker_user.get(legal_ward_user.id)
+    assert set(legal_ward_user.legal_guardians) == set(legal_guardians_record_uids)
