@@ -33,7 +33,12 @@ from pathlib import Path
 import faker
 import pytest
 import pytest_asyncio
-from tenacity import AsyncRetrying, retry_if_exception_type, stop_after_attempt, wait_fixed
+from tenacity import (
+    AsyncRetrying,
+    retry_if_exception_type,
+    stop_after_attempt,
+    wait_fixed,
+)
 
 import ucsschool_id_connector.plugin_loader
 from ucsschool.kelvin.client import User as KelvinUser
@@ -78,7 +83,9 @@ def new_id_broker_school_auth_conf(
             with attempt:
                 await kelvin_user.save()
         print(f"Created admin user {kelvin_user.name!r}.")
-        print(f"Waiting 10 sec for user {username!r} to be replicated to LDAP of {id_broker_fqdn!r}...")
+        print(
+            f"Waiting 10 sec for user {username!r} to be replicated to LDAP of {id_broker_fqdn!r}..."
+        )
         await asyncio.sleep(10.0)
 
         return school_auth_config_id_broker(s_a_name, password)
@@ -87,7 +94,9 @@ def new_id_broker_school_auth_conf(
 
 
 @pytest_asyncio.fixture()
-def set_school_authority_on_id_connector_special(make_school_authority, new_id_broker_school_auth_conf):
+def set_school_authority_on_id_connector_special(
+    make_school_authority, new_id_broker_school_auth_conf
+):
     """
     Difference to set_school_authority_on_id_connector: instead of using Traeger*
     a custom configuration can be used.
@@ -96,7 +105,9 @@ def set_school_authority_on_id_connector_special(make_school_authority, new_id_b
     async def _func(school):
         config = await new_id_broker_school_auth_conf(school)
         config["plugin_configs"]["id_broker"]["schools"] = [school]
-        school_authority = await make_school_authority(plugin_name="id_broker", **config)
+        school_authority = await make_school_authority(
+            plugin_name="id_broker", **config
+        )
 
         return school_authority
 
@@ -122,9 +133,14 @@ async def test_sync_user_multiple_config_support(
     """
     # save existing school authority configurations
     temp_clear_dir(
-        Path("/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities/")
+        Path(
+            "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities/"
+        )
     )
-    sender_school__authority_1, sender_school__authority_2 = await kelvin_schools_on_sender(2)
+    (
+        sender_school__authority_1,
+        sender_school__authority_2,
+    ) = await kelvin_schools_on_sender(2)
     conf_authority_1 = await set_school_authority_on_id_connector_special(
         school=sender_school__authority_1.name,
     )
@@ -138,10 +154,14 @@ async def test_sync_user_multiple_config_support(
         school_authority=conf_authority_2, schools=[sender_school__authority_2.name]
     )
     sender_user__school_authority_1 = await make_sender_user_special(
-        ous=[sender_school__authority_1.name], s_a_name=conf_authority_1.name, roles=(role,)
+        ous=[sender_school__authority_1.name],
+        s_a_name=conf_authority_1.name,
+        roles=(role,),
     )
     sender_user__school_authority_2 = await make_sender_user_special(
-        ous=[sender_school__authority_2.name], s_a_name=conf_authority_2.name, roles=(role,)
+        ous=[sender_school__authority_2.name],
+        s_a_name=conf_authority_2.name,
+        roles=(role,),
     )
     for school, config, user in [
         (sender_school__authority_1, conf_authority_1, sender_user__school_authority_1),
@@ -159,4 +179,6 @@ async def test_sync_user_multiple_config_support(
                 )
                 for key, value in user["school_classes"].items():
                     assert f"{config.name}-{key}" in remote_user.school_classes
-                    assert set(value) == set(remote_user.school_classes[f"{config.name}-{key}"])
+                    assert set(value) == set(
+                        remote_user.school_classes[f"{config.name}-{key}"]
+                    )
