@@ -76,7 +76,9 @@ async def test_school_exists_after_user_with_non_existing_school_is_synced(
     -> school should be created on id broker side
     -> the display_name should be set correct
     """
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
@@ -84,10 +86,14 @@ async def test_school_exists_after_user_with_non_existing_school_is_synced(
     sender_user: Dict[str, Any] = await make_sender_user_special(
         ous=[kelvin_school_on_sender.name], s_a_name=s_a_name
     )
-    kelvin_school_on_id_broker: KelvinSchool = await wait_for_kelvin_school_on_id_broker(
-        s_a_name=s_a_name, name=sender_user["school"]
+    kelvin_school_on_id_broker: KelvinSchool = (
+        await wait_for_kelvin_school_on_id_broker(
+            s_a_name=s_a_name, name=sender_user["school"]
+        )
+    )
+    assert (
+        kelvin_school_on_id_broker.display_name == kelvin_school_on_sender.display_name
     )
-    assert kelvin_school_on_id_broker.display_name == kelvin_school_on_sender.display_name
 
 
 @pytest.mark.asyncio
@@ -111,13 +117,17 @@ async def test_workgroup_exists_after_user_with_non_existing_workgroup_is_synced
     - change user on id connector side
     -> workgroup should be created
     """
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=kelvin_school_on_sender.name, wokrgroup_name="non-existent"
+    sender_kelvin_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=kelvin_school_on_sender.name, wokrgroup_name="non-existent"
+        )
     )
     sender_user = await make_sender_user_special(
         ous=[kelvin_school_on_sender.name],
@@ -136,7 +146,9 @@ async def test_workgroup_exists_after_user_with_non_existing_workgroup_is_synced
     await id_broker_group.delete(sender_group_id)
     assert await id_broker_group.exists(sender_group_id) is False
     sender_user["description"] = "something to trigger"
-    updated_sender_user = KelvinUser(session=kelvin_session(docker_hostname), **sender_user)
+    updated_sender_user = KelvinUser(
+        session=kelvin_session(docker_hostname), **sender_user
+    )
     updated_sender_user.password = fake.password(
         length=15, special_chars=False
     )  # password must not be used again.
@@ -152,7 +164,9 @@ async def test_workgroup_exists_after_user_with_non_existing_workgroup_is_synced
     "school_wildcard", ("none", "full", "partial"), ids=lambda x: f"school_wildcard={x}"
 )
 @pytest.mark.parametrize(
-    "initial_import_mode", ["unset", True, False], ids=lambda x: f"initial_import_mode={x}"
+    "initial_import_mode",
+    ["unset", True, False],
+    ids=lambda x: f"initial_import_mode={x}",
 )
 @pytest.mark.parametrize("role", ["student", "teacher", "legal_guardian"])
 @pytest.mark.asyncio
@@ -189,7 +203,8 @@ async def test_sync_user(
         raise ValueError(f"Invalid school_wildcard {school_wildcard}")
     school_authority = await set_school_authority_on_id_connector(schools=school_filter)
     await schedule_schools_delete(
-        school_authority=school_authority, schools=[sender_school_1.name, sender_school_2.name]
+        school_authority=school_authority,
+        schools=[sender_school_1.name, sender_school_2.name],
     )
     s_a_name = school_authority.name
     sender_user: Dict[str, Any] = await make_sender_user_special(
@@ -201,7 +216,9 @@ async def test_sync_user(
     remote_user: KelvinUser = await wait_for_kelvin_user_on_id_broker(
         s_a_name=s_a_name, school=sender_school_1.name, name=sender_user["name"]
     )
-    assert sorted(f"{s_a_name}-{s}" for s in sender_user["schools"]) == sorted(remote_user.schools)
+    assert sorted(f"{s_a_name}-{s}" for s in sender_user["schools"]) == sorted(
+        remote_user.schools
+    )
 
     if role == "legal_guardian":
         assert set(remote_user.legal_wards) == set(
@@ -223,12 +240,18 @@ async def test_sync_user(
         ):
             with attempt:
                 for key, value in sender_user["school_classes"].items():
-                    assert set(value) == set(remote_user.school_classes[f"{s_a_name}-{key}"])
+                    assert set(value) == set(
+                        remote_user.school_classes[f"{s_a_name}-{key}"]
+                    )
 
 
-@pytest.mark.parametrize("school_wildcard", ("none", "partial"), ids=lambda x: f"school_wildcard={x}")
 @pytest.mark.parametrize(
-    "initial_import_mode", ["unset", True, False], ids=lambda x: f"initial_import_mode={x}"
+    "school_wildcard", ("none", "partial"), ids=lambda x: f"school_wildcard={x}"
+)
+@pytest.mark.parametrize(
+    "initial_import_mode",
+    ["unset", True, False],
+    ids=lambda x: f"initial_import_mode={x}",
 )
 @pytest.mark.parametrize("role", ["student", "teacher", "legal_guardian"])
 @pytest.mark.asyncio
@@ -250,11 +273,16 @@ async def test_sync_only_user_with_configured_school(
         id_broker_school_auth_conf["plugin_configs"]["id_broker"][
             "initial_import_mode"
         ] = initial_import_mode
-    un_configured_sender_school, configured_sender_school = await kelvin_schools_on_sender(2)
+    (
+        un_configured_sender_school,
+        configured_sender_school,
+    ) = await kelvin_schools_on_sender(2)
     if school_wildcard == "none":
         school_filter = [configured_sender_school.name]
     elif school_wildcard == "partial":
-        school_filter = [f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"]
+        school_filter = [
+            f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"
+        ]
         if (
             f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"
             == f"{un_configured_sender_school.name[0]}*{un_configured_sender_school.name[2:]}"
@@ -278,9 +306,13 @@ async def test_sync_only_user_with_configured_school(
         ous=[configured_sender_school.name], s_a_name=s_a_name, roles=(role,)
     )
     remote_user2: KelvinUser = await wait_for_kelvin_user_on_id_broker(
-        s_a_name=s_a_name, school=configured_sender_school.name, name=sender_user2["name"]
+        s_a_name=s_a_name,
+        school=configured_sender_school.name,
+        name=sender_user2["name"],
+    )
+    assert sorted(f"{s_a_name}-{s}" for s in sender_user2["schools"]) == sorted(
+        remote_user2.schools
     )
-    assert sorted(f"{s_a_name}-{s}" for s in sender_user2["schools"]) == sorted(remote_user2.schools)
     if initial_import_mode == 1:
         assert remote_user2.school_classes == {}
     else:
@@ -292,7 +324,9 @@ async def test_sync_only_user_with_configured_school(
         ):
             with attempt:
                 for key, value in sender_user2["school_classes"].items():
-                    assert set(value) == set(remote_user2.school_classes[f"{s_a_name}-{key}"])
+                    assert set(value) == set(
+                        remote_user2.school_classes[f"{s_a_name}-{key}"]
+                    )
     await wait_for_kelvin_user_on_id_broker(
         s_a_name=s_a_name,
         school=un_configured_sender_school.name,
@@ -302,7 +336,9 @@ async def test_sync_only_user_with_configured_school(
 
 
 @pytest.mark.parametrize(
-    "initial_import_mode", ["unset", True, False], ids=lambda x: f"initial_import_mode={x}"
+    "initial_import_mode",
+    ["unset", True, False],
+    ids=lambda x: f"initial_import_mode={x}",
 )
 @pytest.mark.parametrize("role", ["student", "teacher", "legal_guardian"])
 @pytest.mark.asyncio
@@ -327,7 +363,10 @@ async def test_remove_user_after_last_configured_school_is_removed(
         id_broker_school_auth_conf["plugin_configs"]["id_broker"][
             "initial_import_mode"
         ] = initial_import_mode
-    un_configured_sender_school, configured_sender_school = await kelvin_schools_on_sender(2)
+    (
+        un_configured_sender_school,
+        configured_sender_school,
+    ) = await kelvin_schools_on_sender(2)
     school_authority = await set_school_authority_on_id_connector(
         schools=[configured_sender_school.name]
     )
@@ -335,17 +374,25 @@ async def test_remove_user_after_last_configured_school_is_removed(
         school_authority=school_authority, schools=[configured_sender_school.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_school_un_conf_class: KelvinWorkGroup = await make_kelvin_school_class_on_id_connector(
-        school_name=un_configured_sender_school.name
+    sender_kelvin_school_un_conf_class: KelvinWorkGroup = (
+        await make_kelvin_school_class_on_id_connector(
+            school_name=un_configured_sender_school.name
+        )
     )
-    sender_kelvin_school_conf_class: KelvinWorkGroup = await make_kelvin_school_class_on_id_connector(
-        school_name=configured_sender_school.name
+    sender_kelvin_school_conf_class: KelvinWorkGroup = (
+        await make_kelvin_school_class_on_id_connector(
+            school_name=configured_sender_school.name
+        )
     )
-    sender_kelvin_un_conf_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=un_configured_sender_school.name
+    sender_kelvin_un_conf_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=un_configured_sender_school.name
+        )
     )
-    sender_kelvin_conf_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=configured_sender_school.name
+    sender_kelvin_conf_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=configured_sender_school.name
+        )
     )
     sender_user: Dict[str, Any] = await make_sender_user_special(
         ous=[un_configured_sender_school.name, configured_sender_school.name],
@@ -361,22 +408,32 @@ async def test_remove_user_after_last_configured_school_is_removed(
         },
     )
     remote_user: KelvinUser = await wait_for_kelvin_user_on_id_broker(
-        s_a_name=s_a_name, school=un_configured_sender_school.name, name=sender_user["name"]
+        s_a_name=s_a_name,
+        school=un_configured_sender_school.name,
+        name=sender_user["name"],
     )
     if initial_import_mode == 1:
         assert remote_user.school_classes == {}
         assert remote_user.workgroups == {}
     else:
-        assert set(sender_user["school_classes"][f"{configured_sender_school.name}"]) == set(
+        assert set(
+            sender_user["school_classes"][f"{configured_sender_school.name}"]
+        ) == set(
             remote_user.school_classes[f"{s_a_name}-{configured_sender_school.name}"]
         )
-        assert set(remote_user.school_classes.keys()) == {f"{s_a_name}-{configured_sender_school.name}"}
-        assert set(sender_user["workgroups"][f"{configured_sender_school.name}"]) == set(
-            remote_user.workgroups[f"{s_a_name}-{configured_sender_school.name}"]
-        )
-        assert set(remote_user.workgroups.keys()) == {f"{s_a_name}-{configured_sender_school.name}"}
+        assert set(remote_user.school_classes.keys()) == {
+            f"{s_a_name}-{configured_sender_school.name}"
+        }
+        assert set(
+            sender_user["workgroups"][f"{configured_sender_school.name}"]
+        ) == set(remote_user.workgroups[f"{s_a_name}-{configured_sender_school.name}"])
+        assert set(remote_user.workgroups.keys()) == {
+            f"{s_a_name}-{configured_sender_school.name}"
+        }
     assert remote_user.schools == [f"{s_a_name}-{configured_sender_school.name}"]
-    assert remote_user.ucsschool_roles == [f"{role}:school:{s_a_name}-{configured_sender_school.name}"]
+    assert remote_user.ucsschool_roles == [
+        f"{role}:school:{s_a_name}-{configured_sender_school.name}"
+    ]
     async with Session(**kelvin_session_kwargs(docker_hostname)) as session:
         user = await UserResource(session=session).get(name=sender_user["name"])
         user.schools = [un_configured_sender_school.name]
@@ -395,7 +452,9 @@ async def test_remove_user_after_last_configured_school_is_removed(
 
 
 @pytest.mark.parametrize(
-    "initial_import_mode", ["unset", True, False], ids=lambda x: f"initial_import_mode={x}"
+    "initial_import_mode",
+    ["unset", True, False],
+    ids=lambda x: f"initial_import_mode={x}",
 )
 @pytest.mark.asyncio
 async def test_sync_school_class(
@@ -415,13 +474,17 @@ async def test_sync_school_class(
         id_broker_school_auth_conf["plugin_configs"]["id_broker"][
             "initial_import_mode"
         ] = initial_import_mode
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_school_class: KelvinSchoolClass = await make_kelvin_school_class_on_id_connector(
-        school_name=kelvin_school_on_sender.name,
+    sender_kelvin_school_class: KelvinSchoolClass = (
+        await make_kelvin_school_class_on_id_connector(
+            school_name=kelvin_school_on_sender.name,
+        )
     )
     try:
         await wait_for_kelvin_school_class_on_id_broker(
@@ -438,7 +501,9 @@ async def test_sync_school_class(
 
 
 @pytest.mark.parametrize(
-    "initial_import_mode", ["unset", True, False], ids=lambda x: f"initial_import_mode={x}"
+    "initial_import_mode",
+    ["unset", True, False],
+    ids=lambda x: f"initial_import_mode={x}",
 )
 @pytest.mark.asyncio
 async def test_sync_workgroup(
@@ -458,13 +523,17 @@ async def test_sync_workgroup(
         id_broker_school_auth_conf["plugin_configs"]["id_broker"][
             "initial_import_mode"
         ] = initial_import_mode
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=kelvin_school_on_sender.name,
+    sender_kelvin_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=kelvin_school_on_sender.name,
+        )
     )
     try:
         await wait_for_kelvin_workgroup_on_id_broker(
@@ -490,13 +559,17 @@ async def test_remove_workgroup(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=kelvin_school_on_sender.name,
+    sender_kelvin_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=kelvin_school_on_sender.name,
+        )
     )
     await wait_for_kelvin_workgroup_on_id_broker(
         s_a_name=s_a_name,
@@ -526,13 +599,17 @@ async def test_remove_school_class(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_kelvin_school_class: KelvinWorkGroup = await make_kelvin_school_class_on_id_connector(
-        school_name=kelvin_school_on_sender.name,
+    sender_kelvin_school_class: KelvinWorkGroup = (
+        await make_kelvin_school_class_on_id_connector(
+            school_name=kelvin_school_on_sender.name,
+        )
     )
     await wait_for_kelvin_school_class_on_id_broker(
         s_a_name=s_a_name,
@@ -573,7 +650,9 @@ async def test_school_exists_after_group_with_non_existing_school_is_synced(
         make_group = make_kelvin_workgroup_on_id_connector
     else:
         make_group = make_kelvin_school_class_on_id_connector
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
@@ -581,10 +660,14 @@ async def test_school_exists_after_group_with_non_existing_school_is_synced(
     sender_kelvin_group: group_cls = await make_group(
         school_name=kelvin_school_on_sender.name,
     )
-    kelvin_school_on_id_broker: KelvinSchool = await wait_for_kelvin_school_on_id_broker(
-        s_a_name=s_a_name, name=sender_kelvin_group.school
+    kelvin_school_on_id_broker: KelvinSchool = (
+        await wait_for_kelvin_school_on_id_broker(
+            s_a_name=s_a_name, name=sender_kelvin_group.school
+        )
+    )
+    assert (
+        kelvin_school_on_id_broker.display_name == kelvin_school_on_sender.display_name
     )
-    assert kelvin_school_on_id_broker.display_name == kelvin_school_on_sender.display_name
 
 
 @pytest.mark.asyncio
@@ -609,7 +692,9 @@ async def test_group_handle_attr_description_empty(
     else:
         make_group = make_kelvin_school_class_on_id_connector
         wait_for_group = wait_for_kelvin_school_class_on_id_broker
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
@@ -647,36 +732,48 @@ async def test_handle_attr_users(
     - IDBrokerPerSAGroupDispatcher._handle_attr_name
     - IDBrokerPerSAGroupDispatcher._handle_attr_school
     """
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_user: Dict[str, Any] = await make_sender_user_special(ous=[kelvin_school_on_sender.name])
+    sender_user: Dict[str, Any] = await make_sender_user_special(
+        ous=[kelvin_school_on_sender.name]
+    )
     await wait_for_kelvin_user_on_id_broker(
         s_a_name=s_a_name, name=sender_user["name"], school=kelvin_school_on_sender.name
     )
-    sender_kelvin_school_class: KelvinSchoolClass = await make_kelvin_school_class_on_id_connector(
-        school_name=kelvin_school_on_sender.name,
-        users=[sender_user["name"]],
+    sender_kelvin_school_class: KelvinSchoolClass = (
+        await make_kelvin_school_class_on_id_connector(
+            school_name=kelvin_school_on_sender.name,
+            users=[sender_user["name"]],
+        )
     )
-    sender_kelvin_workgroup: KelvinWorkGroup = await make_kelvin_workgroup_on_id_connector(
-        school_name=kelvin_school_on_sender.name, users=[sender_user["name"]]
+    sender_kelvin_workgroup: KelvinWorkGroup = (
+        await make_kelvin_workgroup_on_id_connector(
+            school_name=kelvin_school_on_sender.name, users=[sender_user["name"]]
+        )
     )
     # The groups are 1st created without users, then the user is created and added to the groups.
     # We'll have to wait with our check until then.
     timeout = datetime.datetime.now() + datetime.timedelta(seconds=SYNC_TIMEOUT)
     while datetime.datetime.now() < timeout:
         used_time = SYNC_TIMEOUT - (timeout - datetime.datetime.now()).seconds
-        kelvin_school_class: KelvinSchoolClass = await wait_for_kelvin_school_class_on_id_broker(
-            s_a_name=s_a_name,
-            school=kelvin_school_on_sender.name,
-            name=sender_kelvin_school_class.name,
+        kelvin_school_class: KelvinSchoolClass = (
+            await wait_for_kelvin_school_class_on_id_broker(
+                s_a_name=s_a_name,
+                school=kelvin_school_on_sender.name,
+                name=sender_kelvin_school_class.name,
+            )
         )
-        kelvin_work_group: KelvinWorkGroup = await wait_for_kelvin_workgroup_on_id_broker(
-            s_a_name=s_a_name,
-            school=kelvin_school_on_sender.name,
-            name=sender_kelvin_workgroup.name,
+        kelvin_work_group: KelvinWorkGroup = (
+            await wait_for_kelvin_workgroup_on_id_broker(
+                s_a_name=s_a_name,
+                school=kelvin_school_on_sender.name,
+                name=sender_kelvin_workgroup.name,
+            )
         )
         try:
             assert kelvin_school_class.users == [f"{s_a_name}-{sender_user['name']}"]
@@ -734,16 +831,24 @@ async def test_group_is_created_with_missing_users(
     else:
         make_group = make_kelvin_school_class_on_id_connector
         wait_for_group = wait_for_kelvin_school_class_on_id_broker
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_user1: Dict[str, Any] = await make_sender_user_special(ous=[kelvin_school_on_sender.name])
-    sender_user2: Dict[str, Any] = await make_sender_user_special(ous=[kelvin_school_on_sender.name])
+    sender_user1: Dict[str, Any] = await make_sender_user_special(
+        ous=[kelvin_school_on_sender.name]
+    )
+    sender_user2: Dict[str, Any] = await make_sender_user_special(
+        ous=[kelvin_school_on_sender.name]
+    )
     for sender_user in (sender_user1, sender_user2):
         await wait_for_kelvin_user_on_id_broker(
-            s_a_name=s_a_name, name=sender_user["name"], school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_user["name"],
+            school=kelvin_school_on_sender.name,
         )
     ldap_access = LDAPAccess()
     results = await ldap_access.search(
@@ -775,7 +880,9 @@ async def test_group_is_created_with_missing_users(
     timeout = datetime.datetime.now() + datetime.timedelta(seconds=SYNC_TIMEOUT)
     while datetime.datetime.now() < timeout:
         kelvin_group: group_cls = await wait_for_group(
-            s_a_name=s_a_name, name=sender_kelvin_group.name, school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_kelvin_group.name,
+            school=kelvin_school_on_sender.name,
         )
         used_time = SYNC_TIMEOUT - (timeout - datetime.datetime.now()).seconds
         try:
@@ -815,16 +922,24 @@ async def test_group_is_updated_with_missing_users(
     else:
         make_group = make_kelvin_school_class_on_id_connector
         wait_for_group = wait_for_kelvin_school_class_on_id_broker
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
-    sender_user1: Dict[str, Any] = await make_sender_user_special(ous=[kelvin_school_on_sender.name])
-    sender_user2: Dict[str, Any] = await make_sender_user_special(ous=[kelvin_school_on_sender.name])
+    sender_user1: Dict[str, Any] = await make_sender_user_special(
+        ous=[kelvin_school_on_sender.name]
+    )
+    sender_user2: Dict[str, Any] = await make_sender_user_special(
+        ous=[kelvin_school_on_sender.name]
+    )
     for sender_user in (sender_user1, sender_user2):
         await wait_for_kelvin_user_on_id_broker(
-            s_a_name=s_a_name, name=sender_user["name"], school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_user["name"],
+            school=kelvin_school_on_sender.name,
         )
     ldap_access = LDAPAccess()
     results = await ldap_access.search(
@@ -852,7 +967,9 @@ async def test_group_is_updated_with_missing_users(
     )
     await sender_kelvin_group.save()
     kelvin_group_on_id_broker: group_cls = await wait_for_group(
-        s_a_name=s_a_name, name=sender_kelvin_group.name, school=kelvin_school_on_sender.name
+        s_a_name=s_a_name,
+        name=sender_kelvin_group.name,
+        school=kelvin_school_on_sender.name,
     )
     assert kelvin_group_on_id_broker.users == []
     sender_kelvin_group.users.extend([sender_user1["name"], sender_user2["name"]])
@@ -862,7 +979,9 @@ async def test_group_is_updated_with_missing_users(
     timeout = datetime.datetime.now() + datetime.timedelta(seconds=SYNC_TIMEOUT)
     while datetime.datetime.now() < timeout:
         kelvin_group_on_id_broker: group_cls = await wait_for_group(
-            s_a_name=s_a_name, name=sender_kelvin_group.name, school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_kelvin_group.name,
+            school=kelvin_school_on_sender.name,
         )
         found = kelvin_group_on_id_broker.users
         used_time = SYNC_TIMEOUT - (timeout - datetime.datetime.now()).seconds
@@ -888,18 +1007,24 @@ async def test_legal_guardian_missing_users(
     """Create some students, sync them, then remove two of them on the ID Broker side
     and create a legal guardian on the sender side which has all of them as legal wards
     """
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
     students: list[dict[str, Any]] = [
-        await make_sender_user_special(ous=[kelvin_school_on_sender.name], roles=("student",))
+        await make_sender_user_special(
+            ous=[kelvin_school_on_sender.name], roles=("student",)
+        )
         for _ in range(3)
     ]
     for sender_user in students:
         await wait_for_kelvin_user_on_id_broker(
-            s_a_name=s_a_name, name=sender_user["name"], school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_user["name"],
+            school=kelvin_school_on_sender.name,
         )
     entry_uuids = []
     ldap_access = LDAPAccess()
@@ -965,18 +1090,24 @@ async def test_legal_ward_missing_users(
     """Create some legal wards, sync them, then remove two of them on the ID Broker side
     and create a legal ward on the sender side which has all of them as legal guards
     """
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     s_a_name = school_authority.name
     legal_guardians: list[dict[str, Any]] = [
-        await make_sender_user_special(ous=[kelvin_school_on_sender.name], roles=("legal_guardian",))
+        await make_sender_user_special(
+            ous=[kelvin_school_on_sender.name], roles=("legal_guardian",)
+        )
         for _ in range(3)
     ]
     for sender_user in legal_guardians:
         await wait_for_kelvin_user_on_id_broker(
-            s_a_name=s_a_name, name=sender_user["name"], school=kelvin_school_on_sender.name
+            s_a_name=s_a_name,
+            name=sender_user["name"],
+            school=kelvin_school_on_sender.name,
         )
     entry_uuids = []
     ldap_access = LDAPAccess()
@@ -1031,7 +1162,9 @@ async def test_legal_ward_missing_users(
     assert set(student_on_id_broker.legal_guardians) == set(entry_uuids)
 
 
-@pytest.mark.parametrize("school_wildcard", ("none", "partial"), ids=lambda x: f"school_wildcard={x}")
+@pytest.mark.parametrize(
+    "school_wildcard", ("none", "partial"), ids=lambda x: f"school_wildcard={x}"
+)
 @pytest.mark.asyncio
 async def test_sync_only_legal_role_with_configured_school(
     school_wildcard,
@@ -1047,11 +1180,16 @@ async def test_sync_only_legal_role_with_configured_school(
     sender_legal_ward1 should never be created
     These users should be filtered from the legal_guardians and legal_wards attribute
     """
-    un_configured_sender_school, configured_sender_school = await kelvin_schools_on_sender(2)
+    (
+        un_configured_sender_school,
+        configured_sender_school,
+    ) = await kelvin_schools_on_sender(2)
     if school_wildcard == "none":
         school_filter = [configured_sender_school.name]
     elif school_wildcard == "partial":
-        school_filter = [f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"]
+        school_filter = [
+            f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"
+        ]
         if (
             f"{configured_sender_school.name[0]}*{configured_sender_school.name[2:]}"
             == f"{un_configured_sender_school.name[0]}*{un_configured_sender_school.name[2:]}"
@@ -1069,23 +1207,33 @@ async def test_sync_only_legal_role_with_configured_school(
     )
     s_a_name = school_authority.name
     sender_legal_guardian1: Dict[str, Any] = await make_sender_user_special(
-        ous=[un_configured_sender_school.name], s_a_name=s_a_name, roles=("legal_guardian",)
+        ous=[un_configured_sender_school.name],
+        s_a_name=s_a_name,
+        roles=("legal_guardian",),
     )
     sender_legal_guardian2: Dict[str, Any] = await make_sender_user_special(
-        ous=[configured_sender_school.name], s_a_name=s_a_name, roles=("legal_guardian",)
+        ous=[configured_sender_school.name],
+        s_a_name=s_a_name,
+        roles=("legal_guardian",),
     )
     # sender_legal_ward1
     await make_sender_user_special(
         ous=[un_configured_sender_school.name],
         s_a_name=s_a_name,
         roles=("student",),
-        legal_guardians=[sender_legal_guardian1["name"], sender_legal_guardian2["name"]],
+        legal_guardians=[
+            sender_legal_guardian1["name"],
+            sender_legal_guardian2["name"],
+        ],
     )
     sender_legal_ward2: Dict[str, Any] = await make_sender_user_special(
         ous=[configured_sender_school.name],
         s_a_name=s_a_name,
         roles=("student",),
-        legal_guardians=[sender_legal_guardian1["name"], sender_legal_guardian2["name"]],
+        legal_guardians=[
+            sender_legal_guardian1["name"],
+            sender_legal_guardian2["name"],
+        ],
     )
     for attempt in Retrying(
         reraise=True,
@@ -1094,13 +1242,21 @@ async def test_sync_only_legal_role_with_configured_school(
         wait=wait_fixed(5),
     ):
         with attempt:
-            remote_legal_guardian2: KelvinUser = await wait_for_kelvin_user_on_id_broker(
-                s_a_name=s_a_name,
-                school=configured_sender_school.name,
-                name=sender_legal_guardian2["name"],
+            remote_legal_guardian2: KelvinUser = (
+                await wait_for_kelvin_user_on_id_broker(
+                    s_a_name=s_a_name,
+                    school=configured_sender_school.name,
+                    name=sender_legal_guardian2["name"],
+                )
             )
             remote_legal_ward2: KelvinUser = await wait_for_kelvin_user_on_id_broker(
-                s_a_name=s_a_name, school=configured_sender_school.name, name=sender_legal_ward2["name"]
+                s_a_name=s_a_name,
+                school=configured_sender_school.name,
+                name=sender_legal_ward2["name"],
             )
-            assert remote_legal_guardian2.legal_wards == [f"{s_a_name}-{sender_legal_ward2['name']}"]
-            assert remote_legal_ward2.legal_guardians == [f"{s_a_name}-{sender_legal_guardian2['name']}"]
+            assert remote_legal_guardian2.legal_wards == [
+                f"{s_a_name}-{sender_legal_ward2['name']}"
+            ]
+            assert remote_legal_ward2.legal_guardians == [
+                f"{s_a_name}-{sender_legal_guardian2['name']}"
+            ]
