@@ -93,7 +93,9 @@ def school_auth_config():
 )
 @pytest.mark.asyncio
 async def test_patch_school_authority_config_fails():
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     with pytest.raises(ManageSchoolsException):
         await manager.patch_school_authority_config(data={})
 
@@ -104,7 +106,9 @@ async def test_patch_school_authority_config_fails():
 )
 @pytest.mark.asyncio
 async def test_patch_school_authority_config_fails_due_to_http_error():
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     with pytest.raises(ManageSchoolsException):
         await manager.patch_school_authority_config(data={})
 
@@ -115,14 +119,18 @@ async def test_patch_school_authority_config_fails_due_to_http_error():
 )
 @pytest.mark.asyncio
 async def test_patch_school_authority_config():
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     await manager.patch_school_authority_config(data=school_auth_config())
 
 
 @pytest.mark.asyncio
 @pytest.mark.parametrize("value", (True, False))
 async def test_set_initial_sync_mode(value):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     manager.patch_school_authority_config = AsyncMock()
     await manager.set_initial_sync_mode(value=value)
     expected_data = {"plugin_configs": {"id_broker": {"initial_import_mode": value}}}
@@ -130,9 +138,13 @@ async def test_set_initial_sync_mode(value):
 
 
 def test__get_config():
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     config = get_school_authority_patch_document(["myschool"])
-    with patch("idbroker.manage_schools_to_sync.read_id_broker_config") as read_id_broker_config_mock:
+    with patch(
+        "idbroker.manage_schools_to_sync.read_id_broker_config"
+    ) as read_id_broker_config_mock:
         read_id_broker_config_mock.configure_mock(return_value=config)
         assert manager.get_config() == config
         read_id_broker_config_mock.assert_called_with(
@@ -143,7 +155,9 @@ def test__get_config():
 @pytest.mark.parametrize("schools", (None, [], ["foo"], ["foo", "BAR"]))
 def test__get_schools_from_config(schools):
     config = school_auth_config()
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     if schools is None:
         del config["plugin_configs"]["id_broker"]["schools"]
     else:
@@ -157,13 +171,17 @@ def test__get_schools_from_config(schools):
 
 @pytest.mark.asyncio
 async def test__restore_old_config():
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
     manager.patch_school_authority_config = AsyncMock()
     await manager.restore_old_config(config)
     manager.patch_school_authority_config.assert_called()
-    manager.patch_school_authority_config = AsyncMock(side_effect=ManageSchoolsException)
+    manager.patch_school_authority_config = AsyncMock(
+        side_effect=ManageSchoolsException
+    )
     with patch("builtins.open", mock_open()) as m, patch("json.dump"):
         await manager.restore_old_config(config)
         m.assert_called_with(f"{CONFIG_PATH}/{'test_authority'}.json", "w")
@@ -175,7 +193,9 @@ async def test__restore_old_config():
     [(True, False), (True, True), (False, False), (False, True)],
 )
 async def test_add_school_to_config(force, already_existing):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=force)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=force
+    )
     school = "myschool"
     if already_existing:
         school_authority_config = get_school_authority_patch_document(schools=[school])
@@ -200,7 +220,10 @@ async def test_add_school_to_config(force, already_existing):
 @pytest.mark.parametrize("active", (True, False))
 def test_check_config_is_active_for_initial_sync(active):
     manager = ManageSchoolsOnIDBroker(
-        school_authority="test_authority", logger=Mock(), num_tasks_for_initial_sync=20, force=False
+        school_authority="test_authority",
+        logger=Mock(),
+        num_tasks_for_initial_sync=20,
+        force=False,
     )
     config = school_auth_config()
     config["plugin_configs"]["id_broker"]["schools"] = ["myschool"]
@@ -216,16 +239,27 @@ def test_check_config_is_active_for_initial_sync(active):
 @pytest.mark.parametrize(
     "schools_filter,matching_schools,mismatch_schools",
     (
-        (["myschool1", "myschool2"], ["myschool1", "myschool2"], ["foo", "bar", "world"]),
+        (
+            ["myschool1", "myschool2"],
+            ["myschool1", "myschool2"],
+            ["foo", "bar", "world"],
+        ),
         (["*"], ["myschool", "foo", "bar"], []),
         (["myschool*"], ["myschool1", "myschool2", "myschool"], ["foo"]),
-        (["my*", "*school*", "myschool", "*"], ["myschool1", "myschool2", "myschool", "foo"], []),
+        (
+            ["my*", "*school*", "myschool", "*"],
+            ["myschool1", "myschool2", "myschool", "foo"],
+            [],
+        ),
     ),
 )
 @pytest.mark.asyncio
 async def test_add_schools(schools_filter, matching_schools, mismatch_schools):
     manager = ManageSchoolsOnIDBroker(
-        school_authority="test_authority", logger=Mock(), num_tasks_for_initial_sync=20, force=False
+        school_authority="test_authority",
+        logger=Mock(),
+        num_tasks_for_initial_sync=20,
+        force=False,
     )
     config = get_school_authority_patch_document(schools_filter)
     manager.get_config = Mock(return_value=config)
@@ -235,10 +269,13 @@ async def test_add_schools(schools_filter, matching_schools, mismatch_schools):
     manager.wait_for_empty_queue = AsyncMock()
     manager.school_scheduler = AsyncMock()
     manager.check_config_is_active_for_initial_sync = Mock()
-    with patch("idbroker.manage_schools_to_sync.setup") as setup_mock, patch(
-        "idbroker.manage_schools_to_sync.sync_complete"
-    ) as sync_complete_mock, patch(
-        "idbroker.manage_schools_to_sync.get_ous", fake_get_ous(matching_schools + mismatch_schools)
+    with (
+        patch("idbroker.manage_schools_to_sync.setup") as setup_mock,
+        patch("idbroker.manage_schools_to_sync.sync_complete") as sync_complete_mock,
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous",
+            fake_get_ous(matching_schools + mismatch_schools),
+        ),
     ):
         await manager.add_schools(schools=schools_filter)
     assert manager.num_tasks == 20
@@ -290,7 +327,10 @@ async def test_add_schools(schools_filter, matching_schools, mismatch_schools):
 @pytest.mark.asyncio
 async def test_add_school_school_does_not_exist():
     manager = ManageSchoolsOnIDBroker(
-        school_authority="test_authority", logger=Mock(), num_tasks_for_initial_sync=20, force=False
+        school_authority="test_authority",
+        logger=Mock(),
+        num_tasks_for_initial_sync=20,
+        force=False,
     )
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
@@ -301,22 +341,24 @@ async def test_add_school_school_does_not_exist():
     manager.school_scheduler = AsyncMock()
     manager.check_config_is_active_for_initial_sync = Mock(return_value=True)
     school_name = "nonexistingschool"
-    with patch("idbroker.manage_schools_to_sync.setup"), patch(
-        "idbroker.manage_schools_to_sync.sync_complete"
-    ), patch("idbroker.manage_schools_to_sync.get_ous", return_value=[]):
+    with (
+        patch("idbroker.manage_schools_to_sync.setup"),
+        patch("idbroker.manage_schools_to_sync.sync_complete"),
+        patch("idbroker.manage_schools_to_sync.get_ous", return_value=[]),
+    ):
         with pytest.raises(ManageSchoolsException):
             await manager.add_schools(schools=[school_name])
 
 
-class MySpecialException(Exception):
-    ...
+class MySpecialException(Exception): ...
 
 
 def test_add_schools_script():
     runner = CliRunner()
-    with patch("idbroker.manage_schools_to_sync.setup_logging"), patch.object(
-        ManageSchoolsOnIDBroker, "add_schools"
-    ) as add_school_mock:
+    with (
+        patch("idbroker.manage_schools_to_sync.setup_logging"),
+        patch.object(ManageSchoolsOnIDBroker, "add_schools") as add_school_mock,
+    ):
         result = runner.invoke(
             add_schools,
             [
@@ -339,12 +381,16 @@ async def test_remove_school_from_config(force, existing):
     schools = []
     if existing:
         schools = ["myschool"]
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=force)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=force
+    )
     manager.get_config = Mock(return_value=get_school_authority_patch_document(schools))
     manager.patch_school_authority_config = AsyncMock()
     manager.safe_current_config = Mock()
     if not force and not existing:
-        with pytest.raises(ManageSchoolsException, match=r"School myschool was already removed"):
+        with pytest.raises(
+            ManageSchoolsException, match=r"School myschool was already removed"
+        ):
             await manager.remove_school_from_config(school="myschool")
     else:
         await manager.remove_school_from_config(school="myschool")
@@ -366,9 +412,13 @@ async def test_remove_school_from_config(force, existing):
     ),
 )
 @pytest.mark.parametrize("force", (True, False), ids=lambda x: f"force-{x}")
-@pytest.mark.parametrize("delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}")
+@pytest.mark.parametrize(
+    "delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}"
+)
 async def test_remove_school(schools_filter, force, delete_schools):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=force)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=force
+    )
     if force:
         config = get_school_authority_patch_document([])
     else:
@@ -376,8 +426,12 @@ async def test_remove_school(schools_filter, force, delete_schools):
     manager.get_config = Mock(return_value=config)
     manager.remove_school_from_config = AsyncMock()
     manager.remove_schools_on_id_broker = AsyncMock()
-    with patch("idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu("myschool")]):
-        await manager.remove_schools(schools=schools_filter, delete_schools=delete_schools)
+    with patch(
+        "idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu("myschool")]
+    ):
+        await manager.remove_schools(
+            schools=schools_filter, delete_schools=delete_schools
+        )
     if delete_schools:
         assert manager.remove_schools_on_id_broker.call_args_list == [
             call(school_filter=s) for s in schools_filter
@@ -387,14 +441,20 @@ async def test_remove_school(schools_filter, force, delete_schools):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}")
+@pytest.mark.parametrize(
+    "delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}"
+)
 async def test_remove_school_wildcard_error(delete_schools):
     # We don't support wildcards for matching config keys
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=True)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=True
+    )
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
     manager.remove_schools_on_id_broker = AsyncMock()
-    with patch("idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu("myschool")]):
+    with patch(
+        "idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu("myschool")]
+    ):
         with pytest.raises(ManageSchoolsException) as excinfo:
             await manager.remove_schools(schools=["my*"], delete_schools=delete_schools)
         assert "Wildcards are not supported" in str(excinfo)
@@ -408,7 +468,9 @@ async def test_remove_school_wildcard_error(delete_schools):
 )
 @pytest.mark.asyncio
 async def test_add_schools_exception_during_execution(exception):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
     manager.restore_old_config = AsyncMock()
@@ -427,9 +489,11 @@ async def test_add_schools_exception_during_execution(exception):
 def test_add_schools_script_exception_during_execution(all_schools, exception):
     runner = CliRunner()
     fake_ous = [FakeOu(school) for school in get_fake_schools()]
-    with patch("idbroker.manage_schools_to_sync.setup_logging"), patch.object(
-        ManageSchoolsOnIDBroker, "add_schools", side_effect=exception
-    ), patch("idbroker.manage_schools_to_sync.get_ous", return_value=fake_ous):
+    with (
+        patch("idbroker.manage_schools_to_sync.setup_logging"),
+        patch.object(ManageSchoolsOnIDBroker, "add_schools", side_effect=exception),
+        patch("idbroker.manage_schools_to_sync.get_ous", return_value=fake_ous),
+    ):
         if all_schools:
             args = [
                 "--num_tasks",
@@ -469,7 +533,9 @@ def test_add_schools_script_exception_during_execution(all_schools, exception):
 )
 @pytest.mark.asyncio
 async def test_remove_school_exception_during_execution(exception):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     manager.remove_school_from_config = AsyncMock(side_effect=exception)
     config = get_school_authority_patch_document()
     manager.get_config = Mock(return_value=config)
@@ -487,9 +553,13 @@ async def test_remove_school_exception_during_execution(exception):
 )
 def test_remove_schools_script_exception_during_execution(all_schools, exception):
     runner = CliRunner()
-    with patch("idbroker.manage_schools_to_sync.setup_logging"), patch.object(
-        ManageSchoolsOnIDBroker, "remove_schools", side_effect=exception
-    ), patch.object(ManageSchoolsOnIDBroker, "get_schools_from_config", return_value=["school1"]):
+    with (
+        patch("idbroker.manage_schools_to_sync.setup_logging"),
+        patch.object(ManageSchoolsOnIDBroker, "remove_schools", side_effect=exception),
+        patch.object(
+            ManageSchoolsOnIDBroker, "get_schools_from_config", return_value=["school1"]
+        ),
+    ):
         if all_schools:
             args = ["--school_authority", "test-authority", "--all_schools"]
         else:
@@ -515,7 +585,9 @@ def test_remove_schools_script_exception_during_execution(all_schools, exception
 )
 @pytest.mark.asyncio
 async def test_configure_schools_exception_during_execution(exception):
-    manager = ManageSchoolsOnIDBroker(school_authority="test_authority", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test_authority", logger=Mock(), force=False
+    )
     manager.add_school_to_config = AsyncMock(side_effect=exception)
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
@@ -534,15 +606,30 @@ async def test_configure_schools_exception_during_execution(exception):
 def test_configure_schools_script_exception_during_execution(all_schools, exception):
     runner = CliRunner()
     fake_ous = [FakeOu(school) for school in get_fake_schools()]
-    with patch("idbroker.manage_schools_to_sync.setup_logging"), patch(
-        "idbroker.manage_schools_to_sync.get_ous", return_value=fake_ous
-    ), patch("idbroker.manage_schools_to_sync.setup_logging"), patch.object(
-        ManageSchoolsOnIDBroker, "configure_schools", side_effect=exception
+    with (
+        patch("idbroker.manage_schools_to_sync.setup_logging"),
+        patch("idbroker.manage_schools_to_sync.get_ous", return_value=fake_ous),
+        patch("idbroker.manage_schools_to_sync.setup_logging"),
+        patch.object(
+            ManageSchoolsOnIDBroker, "configure_schools", side_effect=exception
+        ),
     ):
         if all_schools:
-            args = ["--school_authority", "test-authority", "--initial_sync", "false", "--all_schools"]
+            args = [
+                "--school_authority",
+                "test-authority",
+                "--initial_sync",
+                "false",
+                "--all_schools",
+            ]
         else:
-            args = ["--school_authority", "test-authority", "--initial_sync", "false", "school1"]
+            args = [
+                "--school_authority",
+                "test-authority",
+                "--initial_sync",
+                "false",
+                "school1",
+            ]
         if exception is MySpecialException:
             res = runner.invoke(
                 add_schools,
@@ -560,7 +647,10 @@ def test_configure_schools_script_exception_during_execution(all_schools, except
 @pytest.mark.asyncio
 async def test_wait_for_empty_queue():
     manager = ManageSchoolsOnIDBroker(
-        school_authority="test_authority", logger=Mock(), num_tasks_for_initial_sync=20, force=False
+        school_authority="test_authority",
+        logger=Mock(),
+        num_tasks_for_initial_sync=20,
+        force=False,
     )
     ManageSchoolsOnIDBroker.queue_check_timeout = 0.1
     ManageSchoolsOnIDBroker.queue_check_interval = 0.01
@@ -579,7 +669,10 @@ async def test_wait_for_empty_queue():
 )
 async def test_wait_for_empty_queue_errors_during_query(successful, length):
     manager = ManageSchoolsOnIDBroker(
-        school_authority="test_authority", logger=Mock(), num_tasks_for_initial_sync=20, force=False
+        school_authority="test_authority",
+        logger=Mock(),
+        num_tasks_for_initial_sync=20,
+        force=False,
     )
     ManageSchoolsOnIDBroker.queue_check_timeout = 0.1
     ManageSchoolsOnIDBroker.queue_check_interval = 0.01
@@ -588,12 +681,15 @@ async def test_wait_for_empty_queue_errors_during_query(successful, length):
         AsyncMock(return_value={"errors": ["some error"]}),
     ):
         with pytest.raises(
-            ManageSchoolsException, match="Error while trying to get the length of queue"
+            ManageSchoolsException,
+            match="Error while trying to get the length of queue",
         ):
             await manager.wait_for_empty_queue()
 
 
-@pytest.mark.parametrize("delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}")
+@pytest.mark.parametrize(
+    "delete_schools", (True, False), ids=lambda x: f"delete_schools-{x}"
+)
 @pytest.mark.parametrize("force", (True, False), ids=lambda x: f"force-{x}")
 def test_remove_schools_script(delete_schools, force):
     runner = CliRunner()
@@ -612,12 +708,16 @@ def test_remove_schools_script(delete_schools, force):
             remove_schools,
             args,
         )
-        mock.assert_called_with(schools=("school1", "school2"), delete_schools=delete_schools)
+        mock.assert_called_with(
+            schools=("school1", "school2"), delete_schools=delete_schools
+        )
     assert not result.exception
 
 
 @pytest.mark.parametrize("all_schools", (True, False), ids=lambda x: f"all_schools-{x}")
-@pytest.mark.parametrize("passed_schools", (True, False), ids=lambda x: f"passed_schools-{x}")
+@pytest.mark.parametrize(
+    "passed_schools", (True, False), ids=lambda x: f"passed_schools-{x}"
+)
 def test_remove_schools_script_all_schools(all_schools, passed_schools):
     runner = CliRunner()
     args = [
@@ -628,9 +728,14 @@ def test_remove_schools_script_all_schools(all_schools, passed_schools):
         args += ["--all_schools"]
     if passed_schools:
         args += ["school1", "school2"]
-    with patch.object(ManageSchoolsOnIDBroker, "remove_schools") as remove_schools_mock, patch.object(
-        ManageSchoolsOnIDBroker, "get_schools_from_config", return_value=["testschool"]
-    ) as get_schools_from_config_mock:
+    with (
+        patch.object(ManageSchoolsOnIDBroker, "remove_schools") as remove_schools_mock,
+        patch.object(
+            ManageSchoolsOnIDBroker,
+            "get_schools_from_config",
+            return_value=["testschool"],
+        ) as get_schools_from_config_mock,
+    ):
         result = runner.invoke(
             remove_schools,
             args,
@@ -640,11 +745,15 @@ def test_remove_schools_script_all_schools(all_schools, passed_schools):
             get_schools_from_config_mock.assert_not_called()
             assert isinstance(result.exception, SystemExit)
         elif passed_schools:
-            remove_schools_mock.assert_called_with(schools=("school1", "school2"), delete_schools=True)
+            remove_schools_mock.assert_called_with(
+                schools=("school1", "school2"), delete_schools=True
+            )
             get_schools_from_config_mock.assert_not_called()
             assert not result.exception
         elif all_schools and not passed_schools:
-            remove_schools_mock.assert_called_with(schools=["testschool"], delete_schools=True)
+            remove_schools_mock.assert_called_with(
+                schools=["testschool"], delete_schools=True
+            )
             get_schools_from_config_mock.assert_called()
             assert not result.exception
 
@@ -667,8 +776,11 @@ def test_remove_schools_script_all_schools_no_schools_and_no_all_school_option_r
 def test_remove_schools_script_all_schools_no_schools_left():
     runner = CliRunner()
     args = ["--school_authority", "test-authority", "--all_schools"]
-    with patch.object(ManageSchoolsOnIDBroker, "remove_schools") as remove_schools_mock, patch.object(
-        ManageSchoolsOnIDBroker, "get_schools_from_config", return_value=[]
+    with (
+        patch.object(ManageSchoolsOnIDBroker, "remove_schools") as remove_schools_mock,
+        patch.object(
+            ManageSchoolsOnIDBroker, "get_schools_from_config", return_value=[]
+        ),
     ):
         result = runner.invoke(
             remove_schools,
@@ -694,7 +806,9 @@ def test_add_schools_script_all_schools_no_schools_and_no_all_school_option_rais
 
 
 @pytest.mark.parametrize("all_schools", (True, False), ids=lambda x: f"all_schools-{x}")
-@pytest.mark.parametrize("passed_schools", (True, False), ids=lambda x: f"passed_schools-{x}")
+@pytest.mark.parametrize(
+    "passed_schools", (True, False), ids=lambda x: f"passed_schools-{x}"
+)
 def test_add_schools_script_all_schools(all_schools, passed_schools):
     runner = CliRunner()
     args = [
@@ -705,8 +819,12 @@ def test_add_schools_script_all_schools(all_schools, passed_schools):
         args += ["--all_schools"]
     if passed_schools:
         args += ["school1", "school2"]
-    with patch.object(ManageSchoolsOnIDBroker, "add_schools") as mock, patch(
-        "idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu("testschool")]
+    with (
+        patch.object(ManageSchoolsOnIDBroker, "add_schools") as mock,
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous",
+            return_value=[FakeOu("testschool")],
+        ),
     ):
         result = runner.invoke(
             add_schools,
@@ -729,15 +847,23 @@ def get_fake_schools():
 
 @pytest.mark.asyncio
 async def test_configure_all_schools():
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     manager.add_school_to_config = AsyncMock()
     manager.safe_current_config = Mock()
     manager.restore_old_config = AsyncMock()
     config = school_auth_config()
     config["plugin_configs"]["id_broker"]["schools"] = ["school1", "school2", "school3"]
     school_authority_config = SchoolAuthorityConfigurationPatchDocument(**config)
-    with patch("idbroker.manage_schools_to_sync.get_ous", return_value=get_fake_schools()), patch(
-        "idbroker.manage_schools_to_sync.read_id_broker_config", return_value=school_authority_config
+    with (
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous", return_value=get_fake_schools()
+        ),
+        patch(
+            "idbroker.manage_schools_to_sync.read_id_broker_config",
+            return_value=school_authority_config,
+        ),
     ):
         await manager.configure_schools(schools=["school1", "school2", "school3"])
     assert manager.add_school_to_config.call_count == 3
@@ -748,7 +874,9 @@ async def test_configure_all_schools():
 
 @pytest.mark.asyncio
 async def test_configure_schools_by_name():
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     manager.add_school_to_config = AsyncMock()
     config = get_school_authority_patch_document(["myschool"])
     manager.get_config = Mock(return_value=config)
@@ -761,19 +889,31 @@ async def test_configure_schools_by_name():
 
 def test_all_schools_without_initial_sync_script():
     runner = CliRunner()
-    with patch.object(ManageSchoolsOnIDBroker, "configure_schools") as mock, patch(
-        "idbroker.manage_schools_to_sync.get_ous", return_value=[FakeOu(f"school{i}") for i in range(10)]
+    with (
+        patch.object(ManageSchoolsOnIDBroker, "configure_schools") as mock,
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous",
+            return_value=[FakeOu(f"school{i}") for i in range(10)],
+        ),
     ):
         result = runner.invoke(
             add_schools,
-            ["--school_authority", "test-authority", "--initial_sync", "false", "--all_schools"],
+            [
+                "--school_authority",
+                "test-authority",
+                "--initial_sync",
+                "false",
+                "--all_schools",
+            ],
         )
         mock.assert_called_once()
         assert not result.exception
 
 
 class IDBrokerSchoolMock:
-    def __init__(self, school_authority, plugin_name, school_exists_after_first_attempt):
+    def __init__(
+        self, school_authority, plugin_name, school_exists_after_first_attempt
+    ):
         self.school_exists_after_first_attempt = school_exists_after_first_attempt
         self._delete_called_with = []
         self._exists_called_with = []
@@ -782,7 +922,10 @@ class IDBrokerSchoolMock:
         self._delete_called_with.append(school_id)
 
     async def exists(self, school_id):
-        if self.school_exists_after_first_attempt and school_id not in self._exists_called_with:
+        if (
+            self.school_exists_after_first_attempt
+            and school_id not in self._exists_called_with
+        ):
             self._exists_called_with.append(school_id)
             return True
         self._exists_called_with.append(school_id)
@@ -800,18 +943,30 @@ def get_school_authority_patch_document(schools: List[str] = None):
 @pytest.mark.parametrize(
     "schools_filter,matching_schools,mismatch_schools",
     (
-        (["myschool1", "myschool2"], ["myschool1", "myschool2"], ["foo", "bar", "world"]),
+        (
+            ["myschool1", "myschool2"],
+            ["myschool1", "myschool2"],
+            ["foo", "bar", "world"],
+        ),
         (["*"], ["myschool", "foo", "bar"], []),
         (["myschool*"], ["myschool1", "myschool2", "myschool"], ["foo"]),
-        (["my*", "*school*", "myschool", "*"], ["myschool1", "myschool2", "myschool", "foo"], []),
+        (
+            ["my*", "*school*", "myschool", "*"],
+            ["myschool1", "myschool2", "myschool", "foo"],
+            [],
+        ),
     ),
 )
 @pytest.mark.asyncio
 async def test_remove_schools_on_id_broker(
     schools_filter, matching_schools, mismatch_schools, school_authority_conf
 ):
-    school_authority_conf.plugin_configs["id_broker"]["schools"] = copy.copy(schools_filter)
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+    school_authority_conf.plugin_configs["id_broker"]["schools"] = copy.copy(
+        schools_filter
+    )
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     mock_school_client = IDBrokerSchoolMock(
         school_authority=school_authority_conf,
         plugin_name="id_broker",
@@ -819,14 +974,20 @@ async def test_remove_schools_on_id_broker(
     )
     manager.get_config = lambda: school_authority_conf
     manager.wait_school_deletion_interval = 0.001
-    with patch(
-        "idbroker.manage_schools_to_sync.IDBrokerSchool",
-        return_value=mock_school_client,
-    ), patch(
-        "idbroker.manage_schools_to_sync.get_ous", fake_get_ous(matching_schools + mismatch_schools)
+    with (
+        patch(
+            "idbroker.manage_schools_to_sync.IDBrokerSchool",
+            return_value=mock_school_client,
+        ),
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous",
+            fake_get_ous(matching_schools + mismatch_schools),
+        ),
     ):
         for school_name in schools_filter:
-            school_authority_conf.plugin_configs["id_broker"]["schools"].remove(school_name)
+            school_authority_conf.plugin_configs["id_broker"]["schools"].remove(
+                school_name
+            )
             await manager.remove_schools_on_id_broker(school_filter=school_name)
         assert mock_school_client._delete_called_with == matching_schools
         for mismatch in mismatch_schools:
@@ -837,9 +998,16 @@ async def test_remove_schools_on_id_broker(
 
 
 @pytest.mark.asyncio
-async def test_remove_schools_on_id_broker_skip_configured_school(school_authority_conf):
-    school_authority_conf.plugin_configs["id_broker"]["schools"] = ["myschool11", "myschool*"]
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+async def test_remove_schools_on_id_broker_skip_configured_school(
+    school_authority_conf,
+):
+    school_authority_conf.plugin_configs["id_broker"]["schools"] = [
+        "myschool11",
+        "myschool*",
+    ]
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     mock_school_client = IDBrokerSchoolMock(
         school_authority=school_authority_conf,
         plugin_name="id_broker",
@@ -847,12 +1015,15 @@ async def test_remove_schools_on_id_broker_skip_configured_school(school_authori
     )
     manager.get_config = lambda: school_authority_conf
     manager.wait_school_deletion_interval = 0.001
-    with patch(
-        "idbroker.manage_schools_to_sync.IDBrokerSchool",
-        return_value=mock_school_client,
-    ), patch(
-        "idbroker.manage_schools_to_sync.get_ous",
-        return_value=[FakeOu("myschool11"), FakeOu("myschool22")],
+    with (
+        patch(
+            "idbroker.manage_schools_to_sync.IDBrokerSchool",
+            return_value=mock_school_client,
+        ),
+        patch(
+            "idbroker.manage_schools_to_sync.get_ous",
+            return_value=[FakeOu("myschool11"), FakeOu("myschool22")],
+        ),
     ):
         school_authority_conf.plugin_configs["id_broker"]["schools"].remove("myschool*")
         await manager.remove_schools_on_id_broker(school_filter="myschool*")
@@ -862,25 +1033,34 @@ async def test_remove_schools_on_id_broker_skip_configured_school(school_authori
 
 @pytest.mark.asyncio
 async def test_remove_schools_on_id_broker_school_not_existing(school_authority_conf):
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     mock_school_client = IDBrokerSchoolMock(
         school_authority=school_authority_conf,
         plugin_name="id_broker",
         school_exists_after_first_attempt=False,
     )
     manager.get_config = lambda: school_authority_conf
-    with patch(
-        "idbroker.manage_schools_to_sync.IDBrokerSchool",
-        return_value=mock_school_client,
-    ), patch("idbroker.manage_schools_to_sync.get_ous", return_value=[]):
+    with (
+        patch(
+            "idbroker.manage_schools_to_sync.IDBrokerSchool",
+            return_value=mock_school_client,
+        ),
+        patch("idbroker.manage_schools_to_sync.get_ous", return_value=[]),
+    ):
         with pytest.raises(SystemExit) as exc:
             await manager.remove_schools_on_id_broker(school_filter="myschool")
             assert exc.code == 1
 
 
 @pytest.mark.asyncio
-async def test_remove_schools_on_id_broker_school_existing_after_first_head(school_authority_conf):
-    manager = ManageSchoolsOnIDBroker(school_authority="test-auth", logger=Mock(), force=False)
+async def test_remove_schools_on_id_broker_school_existing_after_first_head(
+    school_authority_conf,
+):
+    manager = ManageSchoolsOnIDBroker(
+        school_authority="test-auth", logger=Mock(), force=False
+    )
     fake_schools = [FakeOu("myschool")]
     mock_school_client = IDBrokerSchoolMock(
         school_authority=school_authority_conf,
@@ -890,10 +1070,13 @@ async def test_remove_schools_on_id_broker_school_existing_after_first_head(scho
     manager.wait_school_deletion_timeout = 1
     manager.wait_school_deletion_interval = 0.01
     manager.get_config = lambda: school_authority_conf
-    with patch(
-        "idbroker.manage_schools_to_sync.IDBrokerSchool",
-        return_value=mock_school_client,
-    ), patch("idbroker.manage_schools_to_sync.get_ous", return_value=fake_schools):
+    with (
+        patch(
+            "idbroker.manage_schools_to_sync.IDBrokerSchool",
+            return_value=mock_school_client,
+        ),
+        patch("idbroker.manage_schools_to_sync.get_ous", return_value=fake_schools),
+    ):
         await manager.remove_schools_on_id_broker(school_filter="myschool")
         assert mock_school_client._delete_called_with == ["myschool"]
         assert mock_school_client._exists_called_with == ["myschool", "myschool"]
