@@ -1,5 +1,5 @@
 import sys
-from typing import Dict, List, Tuple, TypeVar
+from typing import TypeVar
 
 from ucsschool.lib.roles import get_role_info
 
@@ -9,7 +9,7 @@ StrBytes = TypeVar("StrBytes", str, bytes)
 def is_school_user(roles):  # type: (List[str]) -> bool
     for role in roles:
         r, _, _ = get_role_info(role)
-        if r in ["student", "staff", "school_admin", "teacher"]:
+        if r in ["student", "staff", "school_admin", "teacher", "legal_guardian"]:
             return True
     return False
 
@@ -76,7 +76,7 @@ def status_bar(
     percents = "{0:.2f}".format(100 * (iteration / float(total)))
     filled_length = int(round(bar_length * iteration / float(total)))
     bar = "+" * filled_length + "-" * (bar_length - filled_length)
-    out_stream.write("\r%s| %s%s " % (bar, percents, "%")),
+    (out_stream.write("\r%s| %s%s " % (bar, percents, "%")),)
     if iteration == total:
         out_stream.write("\n")
     out_stream.flush()
