@@ -59,7 +59,10 @@ async def get_pseudonyms_for_providers(
     for sp, udm_prop in provider_to_udm_prop.items():
         # todo could be cached for optimization
         service_provider_salt = await get_service_provider_secret(sp)
-        yield udm_prop, generate_pseudonym(service_provider_salt, entry_uuid, school_authority)
+        yield (
+            udm_prop,
+            generate_pseudonym(service_provider_salt, entry_uuid, school_authority),
+        )
 
 
 async def users_of_school(school: str, session: Session):
@@ -67,8 +70,12 @@ async def users_of_school(school: str, session: Session):
 
 
 async def groups_of_school(school: str, session: Session):
-    school_classes = [obj async for obj in SchoolClassResource(session=session).search(school=school)]
-    work_groups = [obj async for obj in WorkGroupResource(session=session).search(school=school)]
+    school_classes = [
+        obj async for obj in SchoolClassResource(session=session).search(school=school)
+    ]
+    work_groups = [
+        obj async for obj in WorkGroupResource(session=session).search(school=school)
+    ]
     return school_classes + work_groups
 
 
