@@ -24,7 +24,9 @@ def setup():
     logger.info(f"Setup of {PLUGIN_NAME} with version {PLUGIN_VERSION}.")
     # load config now to raise exception about errors as early as possible
     settings = load_settings(PLUGIN_SETTINGS_FILE)
-    logger.info("Settings in '%s': %r", PLUGIN_SETTINGS_FILE, remove_passwords(settings))
+    logger.info(
+        "Settings in '%s': %r", PLUGIN_SETTINGS_FILE, remove_passwords(settings)
+    )
     auth_manager.tags[PLUGIN_NAME] = "Tag for all self disclosure API endpoints"
 
 
