@@ -398,7 +398,9 @@ class TestParseCmdline:
                 parse_cmdline()
 
     def test_args_with_keycloak_admin_password_file(self):
-        pwd_filepath = f"/tmp/{datetime.now().strftime('%Y%m%d%H%M')}-fake-keycloak-pwd.txt"
+        pwd_filepath = (
+            f"/tmp/{datetime.now().strftime('%Y%m%d%H%M')}-fake-keycloak-pwd.txt"
+        )
         pwd = "9876543Plm"
         with open(pwd_filepath, "w") as pwd_file:
             pwd_file.write(f"{pwd}\n")
@@ -582,7 +584,9 @@ class TestSchoolAuthCleaner:
             ):
                 sac.keycloak_connection
         finally:
-            remove_school_authority.get_keycloak_connection = old_get_keycloak_connection
+            remove_school_authority.get_keycloak_connection = (
+                old_get_keycloak_connection
+            )
 
     def test_ldap_connection(self):
         sac = SchoolAuthCleaner(**self.DEFAULT_CONFIG)
@@ -598,9 +602,13 @@ class TestSchoolAuthCleaner:
         assert ldap_connection == ldap_connection2
 
     def test_lo_initialization_with_errors(self):
-        old_get_ldap_admin_connection = remove_school_authority.get_ldap_admin_connection
+        old_get_ldap_admin_connection = (
+            remove_school_authority.get_ldap_admin_connection
+        )
         mock_get_ldap_admin_connection = mock.Mock(side_effect=Exception("test error"))
-        remove_school_authority.get_ldap_admin_connection = mock_get_ldap_admin_connection
+        remove_school_authority.get_ldap_admin_connection = (
+            mock_get_ldap_admin_connection
+        )
 
         try:
             sac = SchoolAuthCleaner(**self.DEFAULT_CONFIG)
@@ -610,7 +618,9 @@ class TestSchoolAuthCleaner:
             ):
                 sac.ldap_connection
         finally:
-            remove_school_authority.get_ldap_admin_connection = old_get_ldap_admin_connection
+            remove_school_authority.get_ldap_admin_connection = (
+                old_get_ldap_admin_connection
+            )
 
     def test_udm_connection(self):
         sac = SchoolAuthCleaner(**self.DEFAULT_CONFIG)
@@ -834,7 +844,9 @@ class TestSchoolAuthCleaner:
         sac._delete(school_authority)
 
         # post-delete checks
-        assert idp_name not in [idp["alias"] for idp in sac.keycloak_connection.get_idps()]
+        assert idp_name not in [
+            idp["alias"] for idp in sac.keycloak_connection.get_idps()
+        ]
         assert school1.dn is None
         assert school2.dn is None
         try:
@@ -920,7 +932,9 @@ class TestSchoolAuthCleaner:
         user.delete = old_user_delete
 
         # Script should still delete what it can
-        assert idp_name not in [idp["alias"] for idp in sac.keycloak_connection.get_idps()]
+        assert idp_name not in [
+            idp["alias"] for idp in sac.keycloak_connection.get_idps()
+        ]
         assert school1.dn is None
         assert school2.dn is None
 
@@ -961,7 +975,9 @@ class TestSchoolAuthCleaner:
         school1.remove = old_school1_remove
 
         # Script should still delete what it can
-        assert idp_name not in [idp["alias"] for idp in sac.keycloak_connection.get_idps()]
+        assert idp_name not in [
+            idp["alias"] for idp in sac.keycloak_connection.get_idps()
+        ]
         assert school2.dn is None
         try:
             sac.udm_connection.get("users/user").get(dn=user.dn)
@@ -1049,7 +1065,9 @@ class TestSchoolAuthCleaner:
             remove_school_authority.user_input = old_user_input
 
         # everything should have been deleted
-        assert idp_name not in [idp["alias"] for idp in sac.keycloak_connection.get_idps()]
+        assert idp_name not in [
+            idp["alias"] for idp in sac.keycloak_connection.get_idps()
+        ]
         try:
             School.from_dn(school1.dn, None, sac.ldap_connection)
             assert False, "School1 still exists"
@@ -1200,7 +1218,9 @@ class TestSchoolAuthCleaner:
         sac.clean()
 
         # everything should have been deleted
-        assert idp_name not in [idp["alias"] for idp in sac.keycloak_connection.get_idps()]
+        assert idp_name not in [
+            idp["alias"] for idp in sac.keycloak_connection.get_idps()
+        ]
         try:
             School.from_dn(school1.dn, None, sac.ldap_connection)
             assert False, "School1 still exists"
