@@ -16,7 +16,9 @@ LOCUST_FILES_DIR = os.path.join(BASE_DIR, "performance_tests", "keycloak")
 
 LOCUST_FILE = "get_access_token_from_saml_session.py"
 LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)
-RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "keycloak_get_access_token_from_saml_session")
+RESULT_FILE_BASE_PATH = os.path.join(
+    RESULT_DIR, "keycloak_get_access_token_from_saml_session"
+)
 HOST = "testapp"
 URL_NAMES = [
     "/auth/realms/ID-Broker/auth/login",
