@@ -17,7 +17,9 @@ def no_wait_for_replication(mocker):
     mocker.patch("provisioning_plugin.routes.v1.users.ldap_access")
     mocker.patch("provisioning_plugin.routes.v1.schools.ldap_access")
     mocker.patch("provisioning_plugin.routes.v1.school_classes.ldap_access")
-    mocker.patch("provisioning_plugin.routes.v1.schools.kelvin_on_primary_session_kwargs")
+    mocker.patch(
+        "provisioning_plugin.routes.v1.schools.kelvin_on_primary_session_kwargs"
+    )
 
 
 @pytest.fixture()
