@@ -52,7 +52,9 @@ def test_get_legal_guardian_user(func_client, broker_student):
 
 
 @pytest.mark.parametrize("method,status_code", [("POST", 201), ("PUT", 200)])
-def test_put_post_user(func_client, method, status_code, broker_student, monkeypatch, async_iterable):
+def test_put_post_user(
+    func_client, method, status_code, broker_student, monkeypatch, async_iterable
+):
     _client = func_client(
         custom_overrides={
             provisioning_plugin.dependencies.get_user_by_id: kelvin_student,
@@ -64,7 +66,9 @@ def test_put_post_user(func_client, method, status_code, broker_student, monkeyp
             provisioning_plugin.dependencies.check_for_authority_admin: lambda: True,
         }
     )
-    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(return_value=["Test Value"])
+    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(
+        return_value=["Test Value"]
+    )
     monkeypatch.setattr(
         users,
         "get_pseudonyms_for_providers",
@@ -82,7 +86,9 @@ def test_put_post_user(func_client, method, status_code, broker_student, monkeyp
     assert response.json() == broker_student
 
 
-def test_post_legal_guardian_user(func_client, broker_student, monkeypatch, async_iterable):
+def test_post_legal_guardian_user(
+    func_client, broker_student, monkeypatch, async_iterable
+):
     student = kelvin_student()
     student["legal_guardians"] = [kelvin_student(2)["name"]]
     _client = func_client(
@@ -96,7 +102,9 @@ def test_post_legal_guardian_user(func_client, broker_student, monkeypatch, asyn
             provisioning_plugin.dependencies.check_for_authority_admin: lambda: True,
         }
     )
-    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(return_value=["Test Value"])
+    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(
+        return_value=["Test Value"]
+    )
     monkeypatch.setattr(
         users,
         "get_pseudonyms_for_providers",
@@ -122,7 +130,9 @@ def test_put_user_id_error(func_client, broker_student, monkeypatch, async_itera
             provisioning_plugin.dependencies.check_for_authority_admin: lambda: True,
         }
     )
-    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(return_value=["Test Value"])
+    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(
+        return_value=["Test Value"]
+    )
     monkeypatch.setattr(
         users,
         "get_pseudonyms_for_providers",
@@ -132,7 +142,9 @@ def test_put_user_id_error(func_client, broker_student, monkeypatch, async_itera
     broker_student["id"] = "other-ID"
     response = _client.put(url, json=broker_student)
     assert response.status_code == 422
-    assert response.json() == {"detail": "The user_id must not be changed after creation!"}
+    assert response.json() == {
+        "detail": "The user_id must not be changed after creation!"
+    }
 
 
 @pytest.mark.parametrize("method", ["POST", "PUT"])
@@ -145,7 +157,9 @@ def test_put_post_user_legal_guardian_error(
             provisioning_plugin.dependencies.check_for_authority_admin: lambda: True,
         }
     )
-    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(return_value=["Test Value"])
+    provisioning_plugin.routes.v1.users.ldap_access().search = AsyncMock(
+        return_value=["Test Value"]
+    )
     monkeypatch.setattr(
         users,
         "get_pseudonyms_for_providers",
@@ -166,7 +180,9 @@ def test_put_post_user_legal_guardian_error(
     }
 
 
-def test_post_conflict_kelvin_request(func_client, monkeypatch, broker_student, async_iterable):
+def test_post_conflict_kelvin_request(
+    func_client, monkeypatch, broker_student, async_iterable
+):
     async def post_mock(*args, **kwargs):
         raise InvalidRequest(msg="test", status=409, reason="test-reason")
 
@@ -198,7 +214,9 @@ def test_post_conflict_kelvin_request(func_client, monkeypatch, broker_student,
     url = f"/v1/{DEFAULT_SCHOOL_AUTHORITY}/users"
     response = _client.post(url, json=broker_student)
     assert response.status_code == 409
-    assert response.json() == {"detail": {"conflict_id": broker_student["id"], "msg": "test-reason"}}
+    assert response.json() == {
+        "detail": {"conflict_id": broker_student["id"], "msg": "test-reason"}
+    }
 
 
 def test_delete_user(func_client, broker_student):
@@ -208,5 +226,7 @@ def test_delete_user(func_client, broker_student):
             provisioning_plugin.dependencies.check_for_authority_admin: lambda: True,
         }
     )
-    response = _client.delete(f"/v1/{DEFAULT_SCHOOL_AUTHORITY}/users/{broker_student['id']}")
+    response = _client.delete(
+        f"/v1/{DEFAULT_SCHOOL_AUTHORITY}/users/{broker_student['id']}"
+    )
     assert response.status_code == 204
