@@ -7,7 +7,11 @@ from id_broker_common.kelvin import search_kelvin_obj
 from id_broker_common.utils import remove_prefix
 from provisioning_plugin import dependencies
 from provisioning_plugin.dependencies import member_ids_to_usernames
-from provisioning_plugin.utils import get_roles_for_school, groups_of_school, users_of_school
+from provisioning_plugin.utils import (
+    get_roles_for_school,
+    groups_of_school,
+    users_of_school,
+)
 from tests.unittests.utils import (
     DictObject,
     KelvinSessionMock,
@@ -43,9 +47,12 @@ async def test_search_kelvin_obj(mocker):
 
 @pytest.mark.asyncio
 @pytest.mark.parametrize(
-    "return_value,status_code,exc_type", [([], 404, HTTPException), ([1, 2], 500, HTTPException)]
+    "return_value,status_code,exc_type",
+    [([], 404, HTTPException), ([1, 2], 500, HTTPException)],
 )
-async def test_search_kelvin_obj_http_exception(return_value, status_code, exc_type, mocker):
+async def test_search_kelvin_obj_http_exception(
+    return_value, status_code, exc_type, mocker
+):
     resource_mock = mocker.Mock()
     resource_mock.Meta.kelvin_object.__name__ = "Resource"
     resource_mock.search = mocker.Mock(return_value=AsyncIteratorMock(return_value))
@@ -58,7 +65,9 @@ async def test_search_kelvin_obj_http_exception(return_value, status_code, exc_t
 @pytest.mark.asyncio
 async def test_search_kelvin_obj_invalid_request(mocker):
     resource_mock = mocker.Mock()
-    resource_mock.search = mocker.Mock(side_effect=InvalidRequest(status=422, reason="Unprocessable"))
+    resource_mock.search = mocker.Mock(
+        side_effect=InvalidRequest(status=422, reason="Unprocessable")
+    )
     with pytest.raises(HTTPException) as exc_info:
         await search_kelvin_obj(resource_mock)
     assert exc_info.type == HTTPException
@@ -90,8 +99,13 @@ def test_remove_school_authority_prefix_exc():
         ([], set()),
         (["teacher:school:DEMOSCHOOL"], {"teacher"}),
         [["student:school:DEMOSCHOOL", "teacher:school:OTHERSCHOOL"], {"student"}],
+        (["legal_guardian:school:DEMOSCHOOL"], {"legal_guardian"}),
         (
-            ["teacher:school:DEMOSCHOOL", "staff:school:DEMOSCHOOL", "student:school:OTHERSCHOOL"],
+            [
+                "teacher:school:DEMOSCHOOL",
+                "staff:school:DEMOSCHOOL",
+                "student:school:OTHERSCHOOL",
+            ],
             {"teacher", "staff"},
         ),
         (["teacher:other:DEMOSCHOOL"], set()),
@@ -110,7 +124,10 @@ def test_get_roles_for_schools_exc(role):
 
 @pytest.mark.asyncio
 async def test_member_ids_to_usernames_no_members():
-    assert await member_ids_to_usernames(members=set(), school_authority="TEST-AUTHORITY") == []
+    assert (
+        await member_ids_to_usernames(members=set(), school_authority="TEST-AUTHORITY")
+        == []
+    )
 
 
 @pytest.mark.asyncio
@@ -138,7 +155,9 @@ async def test_member_ids_to_usernames(monkeypatch):
         ldap_access,
     )
     assert sorted(
-        await member_ids_to_usernames(members=members, school_authority="TEST-AUTHORITY")
+        await member_ids_to_usernames(
+            members=members, school_authority="TEST-AUTHORITY"
+        )
     ) == sorted(members)
 
 
