@@ -14,9 +14,12 @@ os.environ["REDIS_OM_URL"] = "redis://127.0.0.1:12345"
 from id_broker_common.models import RawUser  # noqa: E402
 from id_broker_common.utils import remove_prefix  # noqa: E402
 from self_disclosure_plugin import dependencies  # noqa: E402
-from self_disclosure_plugin.models import GroupMembers, Student, Teacher  # noqa: E402
+from self_disclosure_plugin.models import GroupMembers, LegalGuardian, Student, Teacher  # noqa: E402
 from self_disclosure_plugin.rest_sddb import SdDBRestClientImpl  # noqa: E402
-from self_disclosure_plugin.routes.v1 import groups as groups_module, users as users_module  # noqa: E402
+from self_disclosure_plugin.routes.v1 import (  # noqa: E402
+    groups as groups_module,
+    users as users_module,
+)  # noqa: E402
 from self_disclosure_plugin.routes.v1.groups import router as groups_router  # noqa: E402
 from self_disclosure_plugin.routes.v1.users import router as users_router  # noqa: E402
 from self_disclosure_plugin.sddb_client import APIQueueEntryType  # noqa: E402
@@ -80,6 +83,7 @@ student1 = DictObject(
     schools=[f"{traeger1}-demoschool"],
     source_uid=traeger1,
     ucsschool_roles=[f"student:school:{traeger1}-demoschool"],
+    legal_guardians=[],
 )
 student2 = DictObject(
     __name__=f"{traeger1}-student2",  # needed for parametrize
@@ -98,6 +102,7 @@ student2 = DictObject(
     schools=[f"{traeger1}-demoschool"],
     source_uid=traeger1,
     ucsschool_roles=[f"student:school:{traeger1}-demoschool"],
+    legal_guardians=[],
 )
 student3 = DictObject(
     __name__=f"{traeger1}-student3",  # needed for parametrize
@@ -116,6 +121,7 @@ student3 = DictObject(
     schools=[f"{traeger1}-demoschool"],
     source_uid=traeger1,
     ucsschool_roles=[f"student:school:{traeger1}-demoschool"],
+    legal_guardians=[],
 )
 student4 = DictObject(
     __name__=f"{traeger1}-student4",  # needed for parametrize
@@ -134,6 +140,7 @@ student4 = DictObject(
     schools=[f"{traeger1}-demoschool"],
     source_uid=traeger1,
     ucsschool_roles=[f"student:school:{traeger1}-demoschool"],
+    legal_guardians=[],
 )
 teacher1 = Dictable(
     __name__=f"{traeger1}-teacher1",  # needed for parametrize
@@ -153,6 +160,25 @@ teacher1 = Dictable(
     source_uid=traeger1,
     ucsschool_roles=[f"teacher:school:{traeger1}-demoschool"],
 )
+legal_guardian1 = Dictable(
+    __name__=f"{traeger1}-legal_guardian1",  # needed for parametrize
+    udm_properties={
+        service_provider_attribute: "le1@Pseudonym",
+        unused_sp_attr: None,
+        "entryUUID": "le1-entry-uuid",
+    },
+    name=f"{traeger1}-legal_guardian1",
+    roles=["legal_guardian"],
+    firstname="le1",
+    lastname="gal",
+    school_classes={f"{traeger1}-demoschool": ["class1"]},
+    workgroups={f"{traeger1}-demoschool": ["workgroup1"]},
+    school=f"{traeger1}-demoschool",
+    schools=[f"{traeger1}-demoschool"],
+    source_uid=traeger1,
+    ucsschool_roles=[f"legal_guardian:school:{traeger1}-demoschool"],
+    legal_wards=[],
+)
 class1 = Dictable(
     name="class1",
     type="school_class",
@@ -160,6 +186,7 @@ class1 = Dictable(
         student1.name,
         student2.name,
         teacher1.name,
+        legal_guardian1.name,
     ],
     school=f"{traeger1}-demoschool",
     udm_properties={
@@ -188,6 +215,7 @@ workgroup1 = Dictable(
         student1.name,
         student2.name,
         teacher1.name,
+        legal_guardian1.name,
     ],
     school=f"{traeger1}-demoschool",
     udm_properties={
@@ -215,6 +243,7 @@ all_test_objects: Dict[str, DictObject] = {
     student3.name: student3,
     student4.name: student4,
     teacher1.name: teacher1,
+    legal_guardian1.name: legal_guardian1,
     class1.name: class1,
     class2.name: class2,
     workgroup1.name: workgroup1,
@@ -230,15 +259,21 @@ def get_obj_by_name(ou, obj_name):
 
 
 def to_flat_groups(ou_groups):
-    return [get_obj_by_name(ou, group_name) for ou, groups in ou_groups.items() for group_name in groups]
+    return [
+        get_obj_by_name(ou, group_name)
+        for ou, groups in ou_groups.items()
+        for group_name in groups
+    ]
 
 
 def kelvin_mock_user_to_sddb_user(user) -> SddbUser:
     school_classes_uuid = [
-        group["udm_properties"]["entryUUID"] for group in to_flat_groups(user["school_classes"])
+        group["udm_properties"]["entryUUID"]
+        for group in to_flat_groups(user["school_classes"])
     ]
     workgroups_uuid = [
-        group["udm_properties"]["entryUUID"] for group in to_flat_groups(user["workgroups"])
+        group["udm_properties"]["entryUUID"]
+        for group in to_flat_groups(user["workgroups"])
     ]
     return SddbUser(
         pseudonym=user["udm_properties"][service_provider_attribute],
@@ -250,6 +285,8 @@ def kelvin_mock_user_to_sddb_user(user) -> SddbUser:
         school_classes=school_classes_uuid,
         workgroups=workgroups_uuid,
         modifyTimestamp=datetime.datetime.now(),
+        legal_guardians=user.get("legal_guardians", []),
+        legal_wards=user.get("legal_wards", []),
         data=user,
     )
 
@@ -265,6 +302,11 @@ def kelvin_mock_group_to_sddb_group(group) -> SddbGroup:
         for name in group["users"]
         if "teacher" in all_test_objects[name].roles
     ]
+    legal_guardians = [
+        all_test_objects[name]["udm_properties"]["entryUUID"]
+        for name in group["users"]
+        if "legal_guardian" in all_test_objects[name].roles
+    ]
     return SddbGroup(
         pseudonym=group["udm_properties"][service_provider_attribute],
         api_version=1,
@@ -275,6 +317,7 @@ def kelvin_mock_group_to_sddb_group(group) -> SddbGroup:
         modifyTimestamp=datetime.datetime.now(),
         students=students,
         teachers=teachers,
+        legal_guardians=legal_guardians,
         data=group,
     )
 
@@ -285,14 +328,18 @@ class SDDBClientMock:
         for pk in pks:
             try:
                 user = [
-                    obj for obj in all_test_objects.values() if pk in obj["udm_properties"].values()
+                    obj
+                    for obj in all_test_objects.values()
+                    if pk in obj["udm_properties"].values()
                 ][0]
             except IndexError:
                 internal_users.append(None)
             else:
                 sddb_user = kelvin_mock_user_to_sddb_user(user)
                 internal_user = SddbInternalUser(id="foo", **sddb_user._asdict())
-                internal_user["p0001"] = user["udm_properties"][service_provider_attribute]
+                internal_user["p0001"] = user["udm_properties"][
+                    service_provider_attribute
+                ]
                 internal_user["p0002"] = user["udm_properties"][unused_sp_attr]
                 internal_users.append(internal_user)
         return internal_users
@@ -310,7 +357,11 @@ def user_to_raw_user(user: DictObject) -> RawUser:
         record_uid="foo",
         schools=user.schools,
         source_uid=user.source_uid,
-        synonyms={k: v for k, v in user.udm_properties.items() if k.startswith("idBrokerPseudonym00")},
+        synonyms={
+            k: v
+            for k, v in user.udm_properties.items()
+            if k.startswith("idBrokerPseudonym00")
+        },
         ucsschool_roles=user.ucsschool_roles,
         username=user.name,
     )
@@ -326,6 +377,7 @@ def student_from_dict_object(obj: DictObject) -> Student:
         username=username_from_user(obj),
         firstname=obj.firstname,
         lastname=obj.lastname,
+        legal_guardians=obj.legal_guardians,
     )
 
 
@@ -336,11 +388,23 @@ def teacher_from_dict_object(obj: DictObject) -> Teacher:
     )
 
 
+def legal_guardian_from_dict_object(obj: DictObject) -> LegalGuardian:
+    return LegalGuardian(
+        user_id=obj.udm_properties[service_provider_attribute],
+        username=username_from_user(obj),
+        firstname=obj.firstname,
+        lastname=obj.lastname,
+        legal_wards=obj.legal_wards,
+    )
+
+
 def get_user_mock(pseudonym: str, service_provider: str) -> SddbUser:
     try:
-        user = [obj for obj in all_test_objects.values() if pseudonym in obj["udm_properties"].values()][
-            0
-        ]
+        user = [
+            obj
+            for obj in all_test_objects.values()
+            if pseudonym in obj["udm_properties"].values()
+        ][0]
     except IndexError:
         raise NotFoundError
     return kelvin_mock_user_to_sddb_user(user)
@@ -348,14 +412,18 @@ def get_user_mock(pseudonym: str, service_provider: str) -> SddbUser:
 
 def test_users_metadata(client, monkeypatch):
     monkeypatch.setattr(
-        dependencies, "get_user", MagicMock(return_value=kelvin_mock_user_to_sddb_user(student1))
+        dependencies,
+        "get_user",
+        MagicMock(return_value=kelvin_mock_user_to_sddb_user(student1)),
     )
     test_client = client(
         router=users_router,
         sub=student1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{student1.udm_properties[service_provider_attribute]}/metadata")
+    response = test_client.get(
+        f"/{student1.udm_properties[service_provider_attribute]}/metadata"
+    )
     assert response.status_code == 200, response.__dict__
     json_response = response.json()
     school_authority_prefix = f"{student1.source_uid}-"
@@ -367,11 +435,15 @@ def test_users_metadata(client, monkeypatch):
         "type": student1.roles[0],
         "school_id": remove_prefix(student1.school, school_authority_prefix),
         "school_authority": student1.source_uid,
+        "legal_guardians": [],
+        "legal_wards": [],
     }
     assert json_response == expected_user
 
 
-@pytest.mark.parametrize("user", [student1, student2, student3, student4, teacher1])
+@pytest.mark.parametrize(
+    "user", [student1, student2, student3, student4, teacher1, legal_guardian1]
+)
 def test_user_groups(client, monkeypatch, user):
     def get_group_by_id_mock(group_id, service_provider):
         for obj in all_test_objects.values():
@@ -380,7 +452,9 @@ def test_user_groups(client, monkeypatch, user):
         raise KeyError
 
     monkeypatch.setattr(
-        dependencies, "get_user", MagicMock(return_value=kelvin_mock_user_to_sddb_user(user))
+        dependencies,
+        "get_user",
+        MagicMock(return_value=kelvin_mock_user_to_sddb_user(user)),
     )
     monkeypatch.setattr(
         dependencies,
@@ -397,7 +471,9 @@ def test_user_groups(client, monkeypatch, user):
         sub=teacher1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{user.udm_properties[service_provider_attribute]}/groups")
+    response = test_client.get(
+        f"/{user.udm_properties[service_provider_attribute]}/groups"
+    )
     assert response.status_code == 200, response.__dict__
     json_response = response.json()
     school_authority, school_id = class1.school.split("-", 1)
@@ -443,7 +519,9 @@ def test_group_users(group, client, monkeypatch):
         sub=teacher1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{group.udm_properties[service_provider_attribute]}/users")
+    response = test_client.get(
+        f"/{group.udm_properties[service_provider_attribute]}/users"
+    )
     assert response.status_code == 200, response.__dict__
     json_response = response.json()
     expected_group = {
@@ -453,12 +531,14 @@ def test_group_users(group, client, monkeypatch):
                 "username": username_from_user(student1),
                 "firstname": student1.firstname,
                 "lastname": student1.lastname,
+                "legal_guardians": [],
             },
             {
                 "user_id": student2.udm_properties[service_provider_attribute],
                 "username": username_from_user(student2),
                 "firstname": student2.firstname,
                 "lastname": student2.lastname,
+                "legal_guardians": [],
             },
         ],
         "teachers": [
@@ -467,6 +547,15 @@ def test_group_users(group, client, monkeypatch):
                 "username": username_from_user(teacher1),
             }
         ],
+        "legal_guardians": [
+            {
+                "user_id": legal_guardian1.udm_properties[service_provider_attribute],
+                "username": username_from_user(legal_guardian1),
+                "firstname": legal_guardian1.firstname,
+                "lastname": legal_guardian1.lastname,
+                "legal_wards": [],
+            }
+        ],
     }
     assert json_response == expected_group
 
@@ -479,20 +568,28 @@ def test_extract_members(group, monkeypatch):
         MagicMock(return_value=service_provider_attribute),
     )
     monkeypatch.setattr(dependencies, "sddb_client", SDDBClientMock)
-    classmembers = dependencies.extract_members(kelvin_mock_group_to_sddb_group(group), service_provider)
+    classmembers = dependencies.extract_members(
+        kelvin_mock_group_to_sddb_group(group), service_provider
+    )
     assert classmembers == GroupMembers(
-        students=[student_from_dict_object(student1), student_from_dict_object(student2)],
+        students=[
+            student_from_dict_object(student1),
+            student_from_dict_object(student2),
+        ],
         teachers=[teacher_from_dict_object(teacher1)],
+        legal_guardians=[legal_guardian_from_dict_object(legal_guardian1)],
     )
 
 
-@pytest.mark.parametrize("user", [student1, teacher1])
+@pytest.mark.parametrize("user", [student1, teacher1, legal_guardian1])
 def test_roles_in_school(user):
     roles = dependencies.roles_in_school(user.ucsschool_roles, user.school)
     assert roles == set(user.roles)
 
 
-def test_get_user_groups_enqueues_missing_in_sddb(client, mocker: MockerFixture, monkeypatch):
+def test_get_user_groups_enqueues_missing_in_sddb(
+    client, mocker: MockerFixture, monkeypatch
+):
     mocker.patch.object(
         dependencies,
         "get_service_provider_attribute",
@@ -504,11 +601,14 @@ def test_get_user_groups_enqueues_missing_in_sddb(client, mocker: MockerFixture,
         MagicMock(side_effect=NotFoundError),
     )
     monkeypatch.setattr(
-        dependencies, "get_user", MagicMock(return_value=kelvin_mock_user_to_sddb_user(student1))
+        dependencies,
+        "get_user",
+        MagicMock(return_value=kelvin_mock_user_to_sddb_user(student1)),
     )
     sddb_rest_client_mock = mocker.MagicMock(spec_set=SdDBRestClientImpl)
     mocker.patch(
-        "self_disclosure_plugin.routes.v1.users.sddb_rest_client", return_value=sddb_rest_client_mock
+        "self_disclosure_plugin.routes.v1.users.sddb_rest_client",
+        return_value=sddb_rest_client_mock,
     )
 
     test_client = client(
@@ -516,7 +616,9 @@ def test_get_user_groups_enqueues_missing_in_sddb(client, mocker: MockerFixture,
         sub=student1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{student1.udm_properties[service_provider_attribute]}/groups")
+    response = test_client.get(
+        f"/{student1.udm_properties[service_provider_attribute]}/groups"
+    )
     assert response.status_code == 200, response.__dict__
     sddb_rest_client_mock.enqueue.assert_has_calls(
         [
@@ -540,7 +642,7 @@ def test_get_user_groups_enqueues_missing_in_sddb(client, mocker: MockerFixture,
     )
 
 
-@pytest.mark.parametrize("user_type", ["student", "teacher"])
+@pytest.mark.parametrize("user_type", ["student", "teacher", "legal_guardian"])
 @pytest.mark.parametrize("group", [class1, workgroup1])
 def test_get_group_members_enqueues_missing_in_sddb(
     user_type, group, client, mocker: MockerFixture, monkeypatch
@@ -569,14 +671,18 @@ def test_get_group_members_enqueues_missing_in_sddb(
     )
     monkeypatch.setattr(dependencies, "sddb_client", SDDBClientMock)
     sddb_rest_client_mock = mocker.MagicMock(spec_set=SdDBRestClientImpl)
-    mocker.patch.object(dependencies, "sddb_rest_client", return_value=sddb_rest_client_mock)
+    mocker.patch.object(
+        dependencies, "sddb_rest_client", return_value=sddb_rest_client_mock
+    )
 
     test_client = client(
         router=groups_router,
         sub=teacher1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{group.udm_properties[service_provider_attribute]}/users")
+    response = test_client.get(
+        f"/{group.udm_properties[service_provider_attribute]}/users"
+    )
     assert response.status_code == 200, response.__dict__
     sddb_rest_client_mock.enqueue.assert_has_calls(
         [
@@ -589,27 +695,35 @@ def test_get_group_members_enqueues_missing_in_sddb(
     )
 
 
-def test_get_connected_user_enqueues_user_missing_in_sddb(client, mocker: MockerFixture, monkeypatch):
+def test_get_connected_user_enqueues_user_missing_in_sddb(
+    client, mocker: MockerFixture, monkeypatch
+):
     mocker.patch.object(
         dependencies,
         "get_service_provider_attribute",
         MagicMock(return_value=service_provider_attribute),
     )
     sddb_rest_client_mock = mocker.MagicMock(spec_set=SdDBRestClientImpl)
-    mocker.patch.object(dependencies, "sddb_rest_client", return_value=sddb_rest_client_mock)
+    mocker.patch.object(
+        dependencies, "sddb_rest_client", return_value=sddb_rest_client_mock
+    )
     mocker.patch("redis_om.model.migrations.migrator.Migrator.detect_migrations")
     monkeypatch.setenv("REDIS_OM_URL", "redis://foo")
     mocker.patch("redis_om.connections.get_redis_connection")
     mocker.patch("redis.commands.core.ManagementCommands.ping")
     mocker.patch("redis_om.model.model.has_redis_json")
-    mocker.patch("redis_om.model.model.RedisModel.find", MagicMock(side_effect=NotFoundError()))
+    mocker.patch(
+        "redis_om.model.model.RedisModel.find", MagicMock(side_effect=NotFoundError())
+    )
 
     test_client = client(
         router=users_router,
         sub=student1.udm_properties[service_provider_attribute],
         client_id=service_provider,
     )
-    response = test_client.get(f"/{student1.udm_properties[service_provider_attribute]}/metadata")
+    response = test_client.get(
+        f"/{student1.udm_properties[service_provider_attribute]}/metadata"
+    )
     assert response.status_code == 401, response.__dict__
     sddb_rest_client_mock.enqueue.assert_called_once()
     assert sddb_rest_client_mock.enqueue.call_args.kwargs == {
